/*
 *ER/Studio 6.5 SQL Code Generation
 * Company :      RIT
 * Project :      expert.dm1
 * Author :       Andrey Kucherov
 *
 * Date Created : Monday, April 23, 2007 08:35:56
 * Target DBMS : Microsoft SQL Server 2000
 */

USE master
go
CREATE DATABASE SROExpert
go
USE SROExpert
go
/* 
 * TABLE: Accreditation 
 */

CREATE TABLE Accreditation(
    AccreditationId      uniqueidentifier    NOT NULL,
    AccreditedId         uniqueidentifier    NOT NULL,
    DocumentId           uniqueidentifier    NULL,
    DateTill             datetime            NULL,
    TariffPlan           char(10)            NULL,
    CertificateDate      datetime            NULL,
    CertificateNumber    char(10)            NULL,
    KickbackPercent      decimal(10, 4)      NULL,
    DateStopped          datetime            NULL,
    StoppingReason       varchar(250)        NULL,
    Created              int                 IDENTITY(1,1),
    CONSTRAINT PK150 PRIMARY KEY NONCLUSTERED (AccreditationId)
)
go



IF OBJECT_ID('Accreditation') IS NOT NULL
    PRINT '<<< CREATED TABLE Accreditation >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Accreditation >>>'
go

/* 
 * TABLE: Accreditation_Line 
 */

CREATE TABLE Accreditation_Line(
    LineOfAccreditationId    uniqueidentifier    NOT NULL,
    AccreditationId          uniqueidentifier    NOT NULL,
    Created                  int                 IDENTITY(1,1),
    CONSTRAINT PK136 PRIMARY KEY NONCLUSTERED (LineOfAccreditationId, AccreditationId)
)
go



IF OBJECT_ID('Accreditation_Line') IS NOT NULL
    PRINT '<<< CREATED TABLE Accreditation_Line >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Accreditation_Line >>>'
go

/* 
 * TABLE: Accreditation_Province 
 */

CREATE TABLE Accreditation_Province(
    ProvinceId         uniqueidentifier    NOT NULL,
    AccreditationId    uniqueidentifier    NOT NULL,
    Created            int                 IDENTITY(1,1),
    CONSTRAINT PK151 PRIMARY KEY NONCLUSTERED (ProvinceId, AccreditationId)
)
go



IF OBJECT_ID('Accreditation_Province') IS NOT NULL
    PRINT '<<< CREATED TABLE Accreditation_Province >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Accreditation_Province >>>'
go

/* 
 * TABLE: Accredited 
 */

CREATE TABLE Accredited(
    AccreditedId                     uniqueidentifier    NOT NULL,
    DocumentId                       uniqueidentifier    NULL,
    RegistrationCertificateDate      datetime            NULL,
    RegistrationCertificateNumber    nvarchar(10)        NULL,
    DateTill                         datetime            NULL,
    TariffPlan                       nvarchar(100)       NULL,
    IsInsurer                        bit                  DEFAULT 0 NOT NULL,
    IsEquityMarketParticipant        bit                  DEFAULT 0 NOT NULL,
    KickbackPercent                  decimal(10, 4)      NULL,
    CONSTRAINT OrganizationPrimaryKey PRIMARY KEY NONCLUSTERED (AccreditedId)
)
go



IF OBJECT_ID('Accredited') IS NOT NULL
    PRINT '<<< CREATED TABLE Accredited >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Accredited >>>'
go

/* 
 * TABLE: Address 
 */

CREATE TABLE Address(
    AddressId      uniqueidentifier    NOT NULL,
    ProvinceId     uniqueidentifier    NOT NULL,
    ZipCode        nvarchar(6)         NULL,
    City           nvarchar(60)        NULL,
    AddressLine    nvarchar(250)       NULL,
    CONSTRAINT AddressPrimaryKey PRIMARY KEY NONCLUSTERED (AddressId)
)
go



IF OBJECT_ID('Address') IS NOT NULL
    PRINT '<<< CREATED TABLE Address >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Address >>>'
go

/* 
 * TABLE: AssetChange 
 */

CREATE TABLE AssetChange(
    AssetChangeId         uniqueidentifier    NOT NULL,
    ManagerProcedureId    uniqueidentifier    NOT NULL,
    EconomicMemberId      uniqueidentifier    NULL,
    DealDate              datetime            NULL,
    Description           ntext               NULL,
    Reason                ntext               NULL,
    Sum                   money               NULL,
    ContragentName        nvarchar(250)       NULL,
    Title                 nvarchar(80)        NULL,
    Note                  ntext               NULL,
    Created               int                 IDENTITY(1,1),
    CONSTRAINT PK143 PRIMARY KEY NONCLUSTERED (AssetChangeId)
)
go



IF OBJECT_ID('AssetChange') IS NOT NULL
    PRINT '<<< CREATED TABLE AssetChange >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE AssetChange >>>'
go

/* 
 * TABLE: Attachment 
 */

CREATE TABLE Attachment(
    AttachmentId    uniqueidentifier    NOT NULL,
    DocumentId      uniqueidentifier    NOT NULL,
    OutcomingId     uniqueidentifier    NOT NULL,
    Name            nvarchar(100)       NULL,
    Note            ntext               NULL,
    Created         int                 IDENTITY(1,1),
    CONSTRAINT AttachmentPrimaryKey PRIMARY KEY NONCLUSTERED (AttachmentId)
)
go



IF OBJECT_ID('Attachment') IS NOT NULL
    PRINT '<<< CREATED TABLE Attachment >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Attachment >>>'
go

/* 
 * TABLE: Audit 
 */

CREATE TABLE Audit(
    AuditId         uniqueidentifier    NOT NULL,
    guilty          bit                 NULL,
    Result          ntext               NULL,
    DisciplineId    uniqueidentifier    NULL,
    CONSTRAINT PK113 PRIMARY KEY NONCLUSTERED (AuditId)
)
go



IF OBJECT_ID('Audit') IS NOT NULL
    PRINT '<<< CREATED TABLE Audit >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Audit >>>'
go

/* 
 * TABLE: BancruptcyProcess 
 */

CREATE TABLE BancruptcyProcess(
    BancruptcyProcessId    uniqueidentifier    NOT NULL,
    ApplicantId            uniqueidentifier    NULL,
    DebtorId               uniqueidentifier    NOT NULL,
    PreviousProcessId      uniqueidentifier    NULL,
    CourtId                uniqueidentifier    NOT NULL,
    ProcedureType          char(1)              DEFAULT 'U' NOT NULL,
    Fee                    money               NULL,
    DealNumber             nvarchar(50)        NULL,
    DealStartDate          datetime            NULL,
    ApplicationDate        datetime            NULL,
    DesignationDate        datetime            NULL,
    DebtorType             char(1)             NOT NULL,
    OrganizationType       char(1)             NOT NULL,
    CONSTRAINT PK121 PRIMARY KEY NONCLUSTERED (BancruptcyProcessId)
)
go



IF OBJECT_ID('BancruptcyProcess') IS NOT NULL
    PRINT '<<< CREATED TABLE BancruptcyProcess >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE BancruptcyProcess >>>'
go

/* 
 * TABLE: BancruptcySubProcess 
 */

CREATE TABLE BancruptcySubProcess(
    BancruptcySubProcessId    uniqueidentifier    NOT NULL,
    ProcedureId               uniqueidentifier    NOT NULL,
    CONSTRAINT PK115 PRIMARY KEY NONCLUSTERED (BancruptcySubProcessId)
)
go



IF OBJECT_ID('BancruptcySubProcess') IS NOT NULL
    PRINT '<<< CREATED TABLE BancruptcySubProcess >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE BancruptcySubProcess >>>'
go

/* 
 * TABLE: Bank 
 */

CREATE TABLE Bank(
    BankId           uniqueidentifier    NOT NULL,
    LegalPersonId    uniqueidentifier    NOT NULL,
    BIK              nvarchar(9)         NULL,
    KS               nvarchar(20)        NULL,
    RKC              nvarchar(250)       NULL,
    Created          int                 IDENTITY(1,1),
    CONSTRAINT PK124 PRIMARY KEY NONCLUSTERED (BankId)
)
go



IF OBJECT_ID('Bank') IS NOT NULL
    PRINT '<<< CREATED TABLE Bank >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Bank >>>'
go

/* 
 * TABLE: BankAccount 
 */

CREATE TABLE BankAccount(
    BankAccountId       uniqueidentifier    NOT NULL,
    EconomicMemberId    uniqueidentifier    NULL,
    BankId              uniqueidentifier    NOT NULL,
    Note                ntext               NULL,
    RS                  nvarchar(20)        NULL,
    IsDefault           bit                  DEFAULT 0 NOT NULL,
    Created             int                 IDENTITY(1,1),
    CONSTRAINT BankAccountPrimaryKey PRIMARY KEY NONCLUSTERED (BankAccountId)
)
go



IF OBJECT_ID('BankAccount') IS NOT NULL
    PRINT '<<< CREATED TABLE BankAccount >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE BankAccount >>>'
go

/* 
 * TABLE: Comission 
 */

CREATE TABLE Comission(
    EconomicMemberId    uniqueidentifier    NOT NULL,
    ProcessId           uniqueidentifier    NOT NULL,
    Note                ntext               NULL,
    Signed              bit                 NULL,
    Agree               bit                 NULL,
    Opinion             ntext               NULL,
    Created             int                 IDENTITY(1,1),
    CONSTRAINT PK114 PRIMARY KEY NONCLUSTERED (EconomicMemberId, ProcessId)
)
go



IF OBJECT_ID('Comission') IS NOT NULL
    PRINT '<<< CREATED TABLE Comission >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Comission >>>'
go

/* 
 * TABLE: Complaint 
 */

CREATE TABLE Complaint(
    ComplaintId       uniqueidentifier    NOT NULL,
    Audit             bit                 NULL,
    Answer            ntext               NULL,
    ShortContent      ntext               NULL,
    WasAbnormality    bit                 NULL,
    AuditId           uniqueidentifier    NULL,
    CONSTRAINT PK75 PRIMARY KEY NONCLUSTERED (ComplaintId)
)
go



IF OBJECT_ID('Complaint') IS NOT NULL
    PRINT '<<< CREATED TABLE Complaint >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Complaint >>>'
go

/* 
 * TABLE: ContactInfo 
 */

CREATE TABLE ContactInfo(
    ContactInfoId       uniqueidentifier    NOT NULL,
    ContactTypeId       uniqueidentifier    NOT NULL,
    EconomicMemberId    uniqueidentifier    NULL,
    Note                ntext               NULL,
    IsPublic            bit                 NULL,
    Created             int                 IDENTITY(1,1),
    CONSTRAINT PK125 PRIMARY KEY NONCLUSTERED (ContactInfoId)
)
go



IF OBJECT_ID('ContactInfo') IS NOT NULL
    PRINT '<<< CREATED TABLE ContactInfo >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE ContactInfo >>>'
go

/* 
 * TABLE: ContactType 
 */

CREATE TABLE ContactType(
    ContactTypeId    uniqueidentifier    NOT NULL,
    Name             nvarchar(50)        NULL,
    Type             char(1)             NULL,
    Created          int                 IDENTITY(1,1),
    CONSTRAINT ContactTypePrimaryKey PRIMARY KEY NONCLUSTERED (ContactTypeId)
)
go



IF OBJECT_ID('ContactType') IS NOT NULL
    PRINT '<<< CREATED TABLE ContactType >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE ContactType >>>'
go

/* 
 * TABLE: DB_global 
 */

CREATE TABLE DB_global(
    Version                char(10)       NULL,
    LastChangeDate         varchar(80)    NULL,
    LastChangedRevision    varchar(80)    NULL
)
go



IF OBJECT_ID('DB_global') IS NOT NULL
    PRINT '<<< CREATED TABLE DB_global >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE DB_global >>>'
go

/* 
 * TABLE: Deal 
 */

CREATE TABLE Deal(
    DealId                 uniqueidentifier    NOT NULL,
    ProcedureReportId      uniqueidentifier    NULL,
    ManagerProcedureId     uniqueidentifier    NULL,
    EconomicMemberId       uniqueidentifier    NOT NULL,
    WorkDescription        nvarchar(250)       NULL,
    DealNumber             nvarchar(10)        NULL,
    DealDate               datetime            NULL,
    isLabourContract       bit                 NOT NULL,
    DealFinalDate          datetime            NULL,
    DealStartDate          datetime            NULL,
    MoneySum               money               NULL,
    MoneySource            nvarchar(250)       NULL,
    Note                   ntext               NULL,
    SourceOfInformation    char(1)             NULL,
    Charged                bit                  DEFAULT 0 NOT NULL,
    DateRegistered         datetime            NOT NULL,
    Created                int                 IDENTITY(1,1),
    CONSTRAINT ManagerOrganizationPrimaryKey PRIMARY KEY NONCLUSTERED (DealId)
)
go



IF OBJECT_ID('Deal') IS NOT NULL
    PRINT '<<< CREATED TABLE Deal >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Deal >>>'
go

/* 
 * TABLE: DealPlan 
 */

CREATE TABLE DealPlan(
    DealPlanId            uniqueidentifier    NOT NULL,
    ManagerProcedureId    uniqueidentifier    NOT NULL,
    EconomicMemberId      uniqueidentifier    NOT NULL,
    Description           ntext               NULL,
    Sum                   money               NULL,
    SumForSRO             money               NULL,
    Note                  ntext               NULL,
    Created               int                 IDENTITY(1,1),
    CONSTRAINT PK141 PRIMARY KEY NONCLUSTERED (DealPlanId)
)
go



IF OBJECT_ID('DealPlan') IS NOT NULL
    PRINT '<<< CREATED TABLE DealPlan >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE DealPlan >>>'
go

/* 
 * TABLE: Discipline 
 */

CREATE TABLE Discipline(
    DisciplineId    uniqueidentifier    NOT NULL,
    Result          ntext               NULL,
    ManagerId       uniqueidentifier    NOT NULL,
    CONSTRAINT PK117 PRIMARY KEY NONCLUSTERED (DisciplineId)
)
go



IF OBJECT_ID('Discipline') IS NOT NULL
    PRINT '<<< CREATED TABLE Discipline >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Discipline >>>'
go

/* 
 * TABLE: Document 
 */

CREATE TABLE Document(
    DocumentId      uniqueidentifier    NOT NULL,
    AuthorId        uniqueidentifier    NOT NULL,
    DateInput       datetime            NOT NULL,
    Type            char(1)             NULL,
    Action          char(2)             NULL,
    Title           nvarchar(250)       NULL,
    Number          nvarchar(30)        NULL,
    EditedNumber    nvarchar(30)        NULL,
    Content         image               NULL,
    ShortContent    ntext               NULL,
    Note            ntext               NULL,
    FileName        nvarchar(250)       NULL,
    Created         int                 IDENTITY(1,1),
    Blocked         bit                  DEFAULT 0 NULL,
    Computer        nvarchar(1024)      NULL,
    Revision        int                  DEFAULT 0 NULL,
    EditorId        uniqueidentifier    NULL,
    CONSTRAINT DocumentPrimaryKey PRIMARY KEY NONCLUSTERED (DocumentId)
)
go



IF OBJECT_ID('Document') IS NOT NULL
    PRINT '<<< CREATED TABLE Document >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Document >>>'
go

/* 
 * TABLE: DocumentAddress 
 */

CREATE TABLE DocumentAddress(
    DocumentAddressId    uniqueidentifier    NOT NULL,
    ZipCode              nvarchar(6)         NULL,
    City                 nvarchar(60)        NULL,
    AddressLine          nvarchar(260)       NULL,
    Province             nvarchar(250)       NULL,
    CONSTRAINT PK134 PRIMARY KEY NONCLUSTERED (DocumentAddressId)
)
go



IF OBJECT_ID('DocumentAddress') IS NOT NULL
    PRINT '<<< CREATED TABLE DocumentAddress >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE DocumentAddress >>>'
go

/* 
 * TABLE: DocumentChannel 
 */

CREATE TABLE DocumentChannel(
    DocumentChannelId    uniqueidentifier    NOT NULL,
    EconomicMemberId     uniqueidentifier    NULL,
    ContactTypeId        uniqueidentifier    NOT NULL,
    IncomingId           uniqueidentifier    NULL,
    DocumentTargetId     uniqueidentifier    NULL,
    Name                 nvarchar(250)       NULL,
    Created              int                 IDENTITY(1,1),
    CONSTRAINT PK133 PRIMARY KEY NONCLUSTERED (DocumentChannelId)
)
go



IF OBJECT_ID('DocumentChannel') IS NOT NULL
    PRINT '<<< CREATED TABLE DocumentChannel >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE DocumentChannel >>>'
go

/* 
 * TABLE: DocumentTarget 
 */

CREATE TABLE DocumentTarget(
    DocumentTargetId      uniqueidentifier    NOT NULL,
    OutcomingId           uniqueidentifier    NOT NULL,
    AuthorId              uniqueidentifier    NOT NULL,
    DatePublication       datetime            NULL,
    SenderId              uniqueidentifier    NULL,
    DateDispatched        datetime            NULL,
    ConfirmatorId         uniqueidentifier    NULL,
    DateConfirmation      datetime            NULL,
    PostRegisterId        uniqueidentifier    NULL,
    Note                  text                NULL,
    DeliveryIsCanceled    bit                  DEFAULT 0 NOT NULL,
    Created               int                 IDENTITY(1,1),
    DatePacking           datetime            NULL,
    PackerId              uniqueidentifier    NULL,
    DateCreation          datetime            NOT NULL,
    PublisherId           uniqueidentifier    NULL,
    CONSTRAINT PK126 PRIMARY KEY NONCLUSTERED (DocumentTargetId)
)
go



IF OBJECT_ID('DocumentTarget') IS NOT NULL
    PRINT '<<< CREATED TABLE DocumentTarget >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE DocumentTarget >>>'
go

/* 
 * TABLE: EconomicMember 
 */

CREATE TABLE EconomicMember(
    EconomicMemberId                 uniqueidentifier    NOT NULL,
    IndustryId                       uniqueidentifier    NULL,
    OKFS                             char(2)             NULL,
    OKOPF                            char(2)             NULL,
    Type                             char(1)              DEFAULT 'S' NOT NULL,
    INN                              char(12)            NULL,
    Note                             ntext               NULL,
    OKPO                             nvarchar(10)        NULL,
    OKVED                            nvarchar(250)       NULL,
    RegistrationDate                 datetime            NULL,
    TaxRegistrationDate              datetime            NULL,
    RegistrationOrganization         nvarchar(250)       NULL,
    RegistrationSertificateNumber    char(10)            NULL,
    RegistrationSertificateSeries    char(10)            NULL,
    Activity                         nvarchar(250)       NULL,
    NumberOfEmployee                 int                 NULL,
    AverageWage                      money               NULL,
    IsLegalPerson                    bit                 NOT NULL,
    IsAlive                          bit                  DEFAULT 1 NOT NULL,
    IsManager                        bit                  DEFAULT 0 NOT NULL,
    IsAccredited                     bit                  DEFAULT 0 NOT NULL,
    IsFilial                         bit                  DEFAULT 0 NOT NULL,
    IsExecutor                       bit                  DEFAULT 0 NOT NULL,
    IsBank                           bit                  DEFAULT 0 NOT NULL,
    IsContragent                     bit                  DEFAULT 1 NOT NULL,
    EGRULExclusionNumber             nvarchar(50)        NULL,
    EGRULExclusionDate               datetime            NULL,
    CONSTRAINT PK106 PRIMARY KEY NONCLUSTERED (EconomicMemberId)
)
go



IF OBJECT_ID('EconomicMember') IS NOT NULL
    PRINT '<<< CREATED TABLE EconomicMember >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE EconomicMember >>>'
go

/* 
 * TABLE: EconomicVariableSnapShot 
 */

CREATE TABLE EconomicVariableSnapShot(
    EconomicVariableSnapShotId    uniqueidentifier    NOT NULL,
    ManagerProcedureId            uniqueidentifier    NOT NULL,
    EconomicVariableTypeId        uniqueidentifier    NOT NULL,
    Value                         decimal(18, 0)      NULL,
    SnapShotDate                  datetime            NOT NULL,
    Created                       int                 IDENTITY(1,1),
    CONSTRAINT PK146 PRIMARY KEY NONCLUSTERED (EconomicVariableSnapShotId)
)
go



IF OBJECT_ID('EconomicVariableSnapShot') IS NOT NULL
    PRINT '<<< CREATED TABLE EconomicVariableSnapShot >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE EconomicVariableSnapShot >>>'
go

/* 
 * TABLE: EconomicVariableType 
 */

CREATE TABLE EconomicVariableType(
    EconomicVariableTypeId    uniqueidentifier    NOT NULL,
    Name                      nvarchar(80)        NULL,
    Code                      nvarchar(20)        NULL,
    Description               nvarchar(250)       NULL,
    version                   char(10)            NULL,
    Created                   int                 IDENTITY(1,1),
    CONSTRAINT PK145 PRIMARY KEY NONCLUSTERED (EconomicVariableTypeId)
)
go



IF OBJECT_ID('EconomicVariableType') IS NOT NULL
    PRINT '<<< CREATED TABLE EconomicVariableType >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE EconomicVariableType >>>'
go

/* 
 * TABLE: Education 
 */

CREATE TABLE Education(
    EducationId      uniqueidentifier    NOT NULL,
    ManagerId        uniqueidentifier    NOT NULL,
    VUZ              ntext               NULL,
    Type             char(1)              DEFAULT 'H' NULL,
    Kind             char(1)             NULL,
    DiplomNumber     nvarchar(15)        NULL,
    DiplomDate       datetime            NULL,
    Qualification    nvarchar(250)       NULL,
    Profession       nvarchar(250)       NULL,
    Created          int                 IDENTITY(1,1),
    CONSTRAINT HigherEducationPrimaryKey PRIMARY KEY NONCLUSTERED (EducationId)
)
go



IF OBJECT_ID('Education') IS NOT NULL
    PRINT '<<< CREATED TABLE Education >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Education >>>'
go

/* 
 * TABLE: Employee 
 */

CREATE TABLE Employee(
    EmployeeId                uniqueidentifier    NOT NULL,
    LegalPersonId             uniqueidentifier    NULL,
    NaturalPersonId           uniqueidentifier    NULL,
    EmployeePositionTypeId    uniqueidentifier    NOT NULL,
    Note                      ntext               NULL,
    Position                  nvarchar(250)       NULL,
    Created                   int                 IDENTITY(1,1),
    CONSTRAINT PK130 PRIMARY KEY NONCLUSTERED (EmployeeId)
)
go



IF OBJECT_ID('Employee') IS NOT NULL
    PRINT '<<< CREATED TABLE Employee >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Employee >>>'
go

/* 
 * TABLE: EmployeePositionType 
 */

CREATE TABLE EmployeePositionType(
    EmployeePositionTypeId    uniqueidentifier    NOT NULL,
    Name                      nvarchar(250)       NULL,
    Created                   int                 IDENTITY(1,1),
    CONSTRAINT PK131 PRIMARY KEY NONCLUSTERED (EmployeePositionTypeId)
)
go



IF OBJECT_ID('EmployeePositionType') IS NOT NULL
    PRINT '<<< CREATED TABLE EmployeePositionType >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE EmployeePositionType >>>'
go

/* 
 * TABLE: Executor 
 */

CREATE TABLE Executor(
    ExecutorId         uniqueidentifier    NOT NULL,
    NaturalPersonId    uniqueidentifier    NOT NULL,
    Login              nvarchar(50)        NOT NULL,
    IsActive           bit                  DEFAULT 1 NULL,
    Created            int                 IDENTITY(1,1),
    AppUserConfig      image               NULL,
    CONSTRAINT PKExecutor PRIMARY KEY NONCLUSTERED (ExecutorId)
)
go



IF OBJECT_ID('Executor') IS NOT NULL
    PRINT '<<< CREATED TABLE Executor >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Executor >>>'
go

/* 
 * TABLE: Executor_role 
 */

CREATE TABLE Executor_role(
    ExecutorId    uniqueidentifier    NOT NULL,
    RoleId        uniqueidentifier    NOT NULL,
    Created       int                 IDENTITY(1,1),
    CONSTRAINT PKExecutor_role PRIMARY KEY NONCLUSTERED (ExecutorId, RoleId)
)
go



IF OBJECT_ID('Executor_role') IS NOT NULL
    PRINT '<<< CREATED TABLE Executor_role >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Executor_role >>>'
go

/* 
 * TABLE: Experience 
 */

CREATE TABLE Experience(
    ExperienceId        uniqueidentifier    NOT NULL,
    IndustryId          uniqueidentifier    NULL,
    ManagerId           uniqueidentifier    NOT NULL,
    EconomicMemberId    uniqueidentifier    NULL,
    IsChief             bit                 NULL,
    Duration            int                 NULL,
    Note                ntext               NULL,
    Started             datetime            NULL,
    Finished            datetime            NULL,
    Position            nvarchar(100)       NULL,
    Location            nvarchar(250)       NULL,
    Created             int                 IDENTITY(1,1),
    Organization        nvarchar(100)       NULL,
    StrategicStat       nvarchar(250)       NULL,
    CONSTRAINT SeniorityPrimaryKey PRIMARY KEY NONCLUSTERED (ExperienceId)
)
go



IF OBJECT_ID('Experience') IS NOT NULL
    PRINT '<<< CREATED TABLE Experience >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Experience >>>'
go

/* 
 * TABLE: ExtensionField 
 */

CREATE TABLE ExtensionField(
    ExtensionFieldId        uniqueidentifier    NOT NULL,
    ExtensionFieldTypeId    uniqueidentifier    NOT NULL,
    SROMemberId             uniqueidentifier    NULL,
    Value                   nvarchar(250)       NULL,
    Created                 int                 IDENTITY(1,1),
    CONSTRAINT ManagerExtensionFieldPrimaryKey PRIMARY KEY NONCLUSTERED (ExtensionFieldId)
)
go



IF OBJECT_ID('ExtensionField') IS NOT NULL
    PRINT '<<< CREATED TABLE ExtensionField >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE ExtensionField >>>'
go

/* 
 * TABLE: ExtensionFieldType 
 */

CREATE TABLE ExtensionFieldType(
    ExtensionFieldTypeId    uniqueidentifier    NOT NULL,
    Name                    nvarchar(50)        NULL,
    Created                 int                 IDENTITY(1,1),
    CONSTRAINT ManagerExtensionFieldTypePrimaryKey PRIMARY KEY NONCLUSTERED (ExtensionFieldTypeId)
)
go



IF OBJECT_ID('ExtensionFieldType') IS NOT NULL
    PRINT '<<< CREATED TABLE ExtensionFieldType >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE ExtensionFieldType >>>'
go

/* 
 * TABLE: ExtraContactInfo 
 */

CREATE TABLE ExtraContactInfo(
    ExtraContactInfoId    uniqueidentifier    NOT NULL,
    Contact               nvarchar(50)        NULL,
    CONSTRAINT ContactInfoPrimaryKey PRIMARY KEY NONCLUSTERED (ExtraContactInfoId)
)
go



IF OBJECT_ID('ExtraContactInfo') IS NOT NULL
    PRINT '<<< CREATED TABLE ExtraContactInfo >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE ExtraContactInfo >>>'
go

/* 
 * TABLE: ExtraDocumentChannel 
 */

CREATE TABLE ExtraDocumentChannel(
    ExtraDocumentChannelId    uniqueidentifier    NOT NULL,
    Contact                   nvarchar(50)        NULL,
    CONSTRAINT PK135 PRIMARY KEY NONCLUSTERED (ExtraDocumentChannelId)
)
go



IF OBJECT_ID('ExtraDocumentChannel') IS NOT NULL
    PRINT '<<< CREATED TABLE ExtraDocumentChannel >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE ExtraDocumentChannel >>>'
go

/* 
 * TABLE: ExtraDocumentRequest 
 */

CREATE TABLE ExtraDocumentRequest(
    ExtraDocumentRequestId    uniqueidentifier    NOT NULL,
    ProcessId                 uniqueidentifier    NOT NULL,
    OutcomingId               uniqueidentifier    NOT NULL,
    IncomingId                uniqueidentifier    NULL,
    RequestText               nvarchar(250)       NULL,
    Answer                    nvarchar(250)       NULL,
    Note                      nvarchar(250)       NULL,
    TargetDate                datetime            NULL,
    ClosingDate               datetime            NULL,
    CONSTRAINT PK128 PRIMARY KEY NONCLUSTERED (ExtraDocumentRequestId)
)
go



IF OBJECT_ID('ExtraDocumentRequest') IS NOT NULL
    PRINT '<<< CREATED TABLE ExtraDocumentRequest >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE ExtraDocumentRequest >>>'
go

/* 
 * TABLE: Filial 
 */

CREATE TABLE Filial(
    FilialId             uniqueidentifier    NOT NULL,
    FilialType           char(1)             NULL,
    HeadAuthorityTill    datetime            NULL,
    FoundationDate       datetime            NULL,
    FoundationReason     varchar(250)        NULL,
    CONSTRAINT RegionalStructurePrimaryKey PRIMARY KEY NONCLUSTERED (FilialId)
)
go



IF OBJECT_ID('Filial') IS NOT NULL
    PRINT '<<< CREATED TABLE Filial >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Filial >>>'
go

/* 
 * TABLE: Incoming 
 */

CREATE TABLE Incoming(
    IncomingId        uniqueidentifier    NOT NULL,
    OriginalNumber    nvarchar(10)        NULL,
    OriginalDate      datetime            NULL,
    DateDispatched    datetime            NULL,
    DateReceived      datetime            NULL,
    CONSTRAINT PK111 PRIMARY KEY NONCLUSTERED (IncomingId)
)
go



IF OBJECT_ID('Incoming') IS NOT NULL
    PRINT '<<< CREATED TABLE Incoming >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Incoming >>>'
go

/* 
 * TABLE: Industry 
 */

CREATE TABLE Industry(
    IndustryId    uniqueidentifier    NOT NULL,
    Name          nvarchar(250)       NULL,
    Note          ntext               NULL,
    Created       int                 IDENTITY(1,1),
    CONSTRAINT PK93 PRIMARY KEY NONCLUSTERED (IndustryId)
)
go



IF OBJECT_ID('Industry') IS NOT NULL
    PRINT '<<< CREATED TABLE Industry >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Industry >>>'
go

/* 
 * TABLE: LegalPerson 
 */

CREATE TABLE LegalPerson(
    LegalPersonId             uniqueidentifier    NOT NULL,
    Name                      nvarchar(250)       NULL,
    ShortName                 nvarchar(200)       NULL,
    KPP                       nvarchar(9)         NULL,
    OGRN                      nvarchar(13)        NULL,
    FixedCapital              money               NULL,
    GovShareInFixedCapital    money               NULL,
    Created                   int                 IDENTITY(1,1),
    CONSTRAINT PK105 PRIMARY KEY NONCLUSTERED (LegalPersonId)
)
go



IF OBJECT_ID('LegalPerson') IS NOT NULL
    PRINT '<<< CREATED TABLE LegalPerson >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE LegalPerson >>>'
go

/* 
 * TABLE: LineOfAccreditation 
 */

CREATE TABLE LineOfAccreditation(
    LineOfAccreditationId    uniqueidentifier    NOT NULL,
    Name                     nvarchar(250)       NULL,
    Created                  int                 IDENTITY(1,1),
    CONSTRAINT PK132 PRIMARY KEY NONCLUSTERED (LineOfAccreditationId)
)
go



IF OBJECT_ID('LineOfAccreditation') IS NOT NULL
    PRINT '<<< CREATED TABLE LineOfAccreditation >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE LineOfAccreditation >>>'
go

/* 
 * TABLE: Manager 
 */

CREATE TABLE Manager(
    ManagerId                           uniqueidentifier    NOT NULL,
    FilialId                            uniqueidentifier    NULL,
    RegisterNumber                      nvarchar(10)        NULL,
    RegistrationCertificateDate         datetime            NULL,
    RegistrationCertificateNumber       nvarchar(10)        NULL,
    StateSecretAccessLevel              int                 NULL,
    IsStrategicalManager                bit                 NULL,
    TExamDate                           datetime            NULL,
    TExamDiplomNumber                   nvarchar(15)        NULL,
    TExamDiplomSeries                   char(10)            NULL,
    InsuranceOrganization               nvarchar(250)       NULL,
    InsuranceDate                       datetime            NULL,
    InsuranceDateTill                   datetime            NULL,
    InsuranceNumber                     nvarchar(100)       NULL,
    InsurancePoliceNumber               nvarchar(100)       NULL,
    InsuranceSum                        money               NULL,
    ExtraProceduresCount                int                 NULL,
    PsychologistResume                  nvarchar(250)       NULL,
    DateOfStart                         datetime            NULL,
    IsNotConvictionTill                 datetime            NULL,
    ChiefDuration                       int                 NULL,
    NotNominative                       bit                  DEFAULT 0 NOT NULL,
    IsTransferedFromOtherSRO            bit                 NOT NULL,
    NotConvictionNumber                 varchar(30)         NULL,
    StateSecretReceivingDate            datetime            NULL,
    StateSecretEndDate                  datetime            NULL,
    StateSecretOrganization             varchar(250)        NULL,
    TEKSeriaNumber                      varchar(30)         NULL,
    TEKDate                             datetime            NULL,
    TEKOrganization                     varchar(250)        NULL,
    CBNumber                            varchar(30)         NULL,
    CBDateTill                          datetime            NULL,
    PPExamDiplomNumber                  varchar(20)         NULL,
    PPExamDiplomDate                    datetime            NULL,
    PPExamVUZ                           varchar(250)        NULL,
    PPExamDescription                   varchar(250)        NULL,
    TExamDiplomDate                     datetime            NULL,
    ProbationCertificateNumber          varchar(10)         NULL,
    ProbationCertificateDate            datetime            NULL,
    ProbationCertificateOrganization    varchar(250)        NULL,
    CONSTRAINT ManagerPrimaryKey PRIMARY KEY NONCLUSTERED (ManagerId)
)
go



IF OBJECT_ID('Manager') IS NOT NULL
    PRINT '<<< CREATED TABLE Manager >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Manager >>>'
go

/* 
 * TABLE: ManagerProcedure 
 */

CREATE TABLE ManagerProcedure(
    ManagerProcedureId                uniqueidentifier    NOT NULL,
    ManagerId                         uniqueidentifier    NOT NULL,
    ExtraFinishReason                 nvarchar(250)       NULL,
    ReportsMode                       char(1)             NULL,
    DateStart                         datetime            NULL,
    DateFinish                        datetime            NULL,
    InsuranceOrganization             nvarchar(250)       NULL,
    InsuranceDate                     datetime            NULL,
    InsuranceDateTill                 datetime            NULL,
    InsuranceNumber                   nvarchar(100)       NULL,
    InsurancePoliceNumber             nvarchar(100)       NULL,
    InsuranceSum                      money               NULL,
    PublicationDate                   datetime            NULL,
    PublicationPlace                  nvarchar(250)       NULL,
    PublicationReleaseNumber          nvarchar(10)        NULL,
    PublicationAdvertisementNumber    nvarchar(10)        NULL,
    ReportDeadline                    datetime            NULL,
    Rating                            int                 NULL,
    DateDebtorInfoReceived            datetime            NULL,
    DebtsDate                         datetime            NULL,
    MainIndexDate1                    datetime            NULL,
    MainIndexDate2                    datetime            NULL,
    CONSTRAINT PK7 PRIMARY KEY NONCLUSTERED (ManagerProcedureId)
)
go



IF OBJECT_ID('ManagerProcedure') IS NOT NULL
    PRINT '<<< CREATED TABLE ManagerProcedure >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE ManagerProcedure >>>'
go

/* 
 * TABLE: MembershipEvent 
 */

CREATE TABLE MembershipEvent(
    MembershipEventId    uniqueidentifier    NOT NULL,
    DocumentId           uniqueidentifier    NULL,
    EventDate            datetime            NOT NULL,
    EventType            char(1)             NOT NULL,
    Note                 ntext               NULL,
    SROMemberId          uniqueidentifier    NOT NULL,
    ExecutorId           uniqueidentifier    NOT NULL,
    Created              int                 IDENTITY(1,1),
    CONSTRAINT SROMemberPrimaryKey PRIMARY KEY NONCLUSTERED (MembershipEventId)
)
go



IF OBJECT_ID('MembershipEvent') IS NOT NULL
    PRINT '<<< CREATED TABLE MembershipEvent >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE MembershipEvent >>>'
go

/* 
 * TABLE: NaturalPerson 
 */

CREATE TABLE NaturalPerson(
    NaturalPersonId    uniqueidentifier    NOT NULL,
    FirstName          nvarchar(25)        NULL,
    MiddleName         nvarchar(25)        NULL,
    LastName           nvarchar(25)        NULL,
    OGRNIP             nvarchar(15)        NULL,
    PassportSeries     nvarchar(4)         NULL,
    PassportNumber     nvarchar(6)         NULL,
    PassportDate       datetime            NULL,
    PassportGiven      nvarchar(250)       NULL,
    Created            int                 IDENTITY(1,1),
    NameNotes          nvarchar(250)       NULL,
    BirthPlace         nvarchar(250)       NULL,
    BirthDate          datetime            NULL,
    Nationality        nvarchar(100)       NULL,
    Languages          nvarchar(250)       NULL,
    AcademicDegrees    ntext               NULL,
    Certificates       nvarchar(250)       NULL,
    CONSTRAINT PK104 PRIMARY KEY NONCLUSTERED (NaturalPersonId)
)
go



IF OBJECT_ID('NaturalPerson') IS NOT NULL
    PRINT '<<< CREATED TABLE NaturalPerson >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE NaturalPerson >>>'
go

/* 
 * TABLE: Offer 
 */

CREATE TABLE Offer(
    OfferId                   uniqueidentifier    NOT NULL,
    RequestId                 uniqueidentifier    NOT NULL,
    ManagerId                 uniqueidentifier    NOT NULL,
    Position_in_final_list    char(1)             NULL,
    agree                     bit                 NULL,
    CONSTRAINT PK120 PRIMARY KEY NONCLUSTERED (OfferId)
)
go



IF OBJECT_ID('Offer') IS NOT NULL
    PRINT '<<< CREATED TABLE Offer >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Offer >>>'
go

/* 
 * TABLE: OrganizationalForm 
 */

CREATE TABLE OrganizationalForm(
    OKOPF      char(2)          NOT NULL,
    Parent     char(2)          NULL,
    Name       nvarchar(250)    NULL,
    Created    int              IDENTITY(1,1),
    CONSTRAINT PK107 PRIMARY KEY NONCLUSTERED (OKOPF)
)
go



IF OBJECT_ID('OrganizationalForm') IS NOT NULL
    PRINT '<<< CREATED TABLE OrganizationalForm >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE OrganizationalForm >>>'
go

/* 
 * TABLE: Outcoming 
 */

CREATE TABLE Outcoming(
    OutcomingId    uniqueidentifier    NOT NULL,
    CONSTRAINT PK112 PRIMARY KEY NONCLUSTERED (OutcomingId)
)
go



IF OBJECT_ID('Outcoming') IS NOT NULL
    PRINT '<<< CREATED TABLE Outcoming >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Outcoming >>>'
go

/* 
 * TABLE: OwnershipForm 
 */

CREATE TABLE OwnershipForm(
    OKFS       char(2)          NOT NULL,
    Parent     char(2)          NULL,
    Name       nvarchar(250)    NULL,
    Created    int              IDENTITY(1,1),
    CONSTRAINT PatternOwnershipPrimaryKey PRIMARY KEY NONCLUSTERED (OKFS)
)
go



IF OBJECT_ID('OwnershipForm') IS NOT NULL
    PRINT '<<< CREATED TABLE OwnershipForm >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE OwnershipForm >>>'
go

/* 
 * TABLE: Payment 
 */

CREATE TABLE Payment(
    PaymentId             uniqueidentifier    NOT NULL,
    SROMemberId           uniqueidentifier    NOT NULL,
    PaymentCategoryId     uniqueidentifier    NULL,
    ManagerProcedureId    uniqueidentifier    NULL,
    DealId                uniqueidentifier    NULL,
    PaymentType           char(2)             NULL,
    PaymentNumber         nvarchar(80)        NULL,
    PaymentDate           datetime            NOT NULL,
    Sum                   money               NULL,
    SumPaid               money               NULL,
    Penalty               money               NULL,
    PenaltyPaid           money               NULL,
    Description           nvarchar(250)       NULL,
    Note                  ntext               NULL,
    DocumentNumber        nvarchar(80)        NULL,
    DocumentDate          datetime            NULL,
    WhoPaid               nvarchar(250)       NULL,
    DeadlineDate          datetime            NULL,
    CustomField           nvarchar(250)       NULL,
    Created               int                 IDENTITY(1,1),
    CONSTRAINT PK110 PRIMARY KEY NONCLUSTERED (PaymentId)
)
go



IF OBJECT_ID('Payment') IS NOT NULL
    PRINT '<<< CREATED TABLE Payment >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Payment >>>'
go

/* 
 * TABLE: PaymentCategory 
 */

CREATE TABLE PaymentCategory(
    PaymentCategoryId    uniqueidentifier    NOT NULL,
    Name                 nvarchar(80)        NULL,
    Created              int                 IDENTITY(1,1),
    CONSTRAINT PK147 PRIMARY KEY NONCLUSTERED (PaymentCategoryId)
)
go



IF OBJECT_ID('PaymentCategory') IS NOT NULL
    PRINT '<<< CREATED TABLE PaymentCategory >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE PaymentCategory >>>'
go

/* 
 * TABLE: PostRegister 
 */

CREATE TABLE PostRegister(
    PostRegisterId    uniqueidentifier    NOT NULL,
    DocumentId        uniqueidentifier    NOT NULL,
    ExecutorId        uniqueidentifier    NOT NULL,
    DateSending       datetime            NULL,
    Created           int                 IDENTITY(1,1),
    CONSTRAINT PK129 PRIMARY KEY NONCLUSTERED (PostRegisterId)
)
go



IF OBJECT_ID('PostRegister') IS NOT NULL
    PRINT '<<< CREATED TABLE PostRegister >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE PostRegister >>>'
go

/* 
 * TABLE: ProcedureReport 
 */

CREATE TABLE ProcedureReport(
    ProcedureReportId              uniqueidentifier    NOT NULL,
    Mark                           char(10)            NULL,
    ResponseDocumentId             uniqueidentifier    NULL,
    WasAbnormality                 bit                 NULL,
    WasLate                        bit                 NULL,
    AnalyzeDescription             text                NULL,
    StartDeadlineDate              datetime            NULL,
    ExportedPackage                ntext               NULL,
    ExportedPackageModelVersion    nvarchar(10)        NULL,
    ReportType                     char(1)             NULL,
    CONSTRAINT PK118 PRIMARY KEY NONCLUSTERED (ProcedureReportId)
)
go



IF OBJECT_ID('ProcedureReport') IS NOT NULL
    PRINT '<<< CREATED TABLE ProcedureReport >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE ProcedureReport >>>'
go

/* 
 * TABLE: Process 
 */

CREATE TABLE Process(
    ProcessId                uniqueidentifier    NOT NULL,
    InitialDocumentId        uniqueidentifier    NULL,
    FinalDocumentId          uniqueidentifier    NULL,
    ExecutorId               uniqueidentifier    NULL,
    Number                   nvarchar(10)        NULL,
    EditedNumber             nvarchar(20)        NULL,
    Note                     ntext               NULL,
    Type                     char(1)             NULL,
    FinishDeadlineDate       datetime            NULL,
    InitialDocumentNumber    nvarchar(30)        NULL,
    FinalDocumentNumber      nvarchar(30)        NULL,
    InitialDocumentDate      datetime            NULL,
    FinalDocumentDate        datetime            NULL,
    State                    char(1)             NULL,
    Created                  int                 IDENTITY(1,1),
    CONSTRAINT PK122 PRIMARY KEY NONCLUSTERED (ProcessId)
)
go



IF OBJECT_ID('Process') IS NOT NULL
    PRINT '<<< CREATED TABLE Process >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Process >>>'
go

/* 
 * TABLE: Process_Document 
 */

CREATE TABLE Process_Document(
    DocumentId    uniqueidentifier    NOT NULL,
    ProcessId     uniqueidentifier    NOT NULL,
    Note          ntext               NULL,
    Created       int                 IDENTITY(1,1),
    CONSTRAINT PK116 PRIMARY KEY NONCLUSTERED (DocumentId, ProcessId)
)
go



IF OBJECT_ID('Process_Document') IS NOT NULL
    PRINT '<<< CREATED TABLE Process_Document >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Process_Document >>>'
go

/* 
 * TABLE: ProcessEvent 
 */

CREATE TABLE ProcessEvent(
    ProcessEventId    uniqueidentifier    NOT NULL,
    EventDate         datetime            NOT NULL,
    EventType         char(1)             NOT NULL,
    Note              ntext               NULL,
    ProcessId         uniqueidentifier    NOT NULL,
    DocumentId        uniqueidentifier    NULL,
    ExecutorId        uniqueidentifier    NOT NULL,
    Created           int                 IDENTITY(1,1),
    CONSTRAINT SROMemberPrimaryKey_1 PRIMARY KEY NONCLUSTERED (ProcessEventId)
)
go



IF OBJECT_ID('ProcessEvent') IS NOT NULL
    PRINT '<<< CREATED TABLE ProcessEvent >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE ProcessEvent >>>'
go

/* 
 * TABLE: PropertyClaim 
 */

CREATE TABLE PropertyClaim(
    PropertyClaimId       uniqueidentifier    NOT NULL,
    ManagerProcedureId    uniqueidentifier    NOT NULL,
    InventoryDocument     nvarchar(250)       NULL,
    Sum                   money               NULL,
    Creditors             ntext               NULL,
    Note                  ntext               NULL,
    Created               int                 IDENTITY(1,1),
    CONSTRAINT PK144 PRIMARY KEY NONCLUSTERED (PropertyClaimId)
)
go



IF OBJECT_ID('PropertyClaim') IS NOT NULL
    PRINT '<<< CREATED TABLE PropertyClaim >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE PropertyClaim >>>'
go

/* 
 * TABLE: Province 
 */

CREATE TABLE Province(
    ProvinceId    uniqueidentifier    NOT NULL,
    Name          nvarchar(250)       NULL,
    Created       int                 IDENTITY(1,1),
    CONSTRAINT PK127 PRIMARY KEY NONCLUSTERED (ProvinceId)
)
go



IF OBJECT_ID('Province') IS NOT NULL
    PRINT '<<< CREATED TABLE Province >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Province >>>'
go

/* 
 * TABLE: Request 
 */

CREATE TABLE Request(
    RequestId            uniqueidentifier    NOT NULL,
    ExtraRequirements    ntext               NULL,
    DecisionNumber       nvarchar(50)        NULL,
    DecisionDate         datetime            NULL,
    CONSTRAINT PK119 PRIMARY KEY NONCLUSTERED (RequestId)
)
go



IF OBJECT_ID('Request') IS NOT NULL
    PRINT '<<< CREATED TABLE Request >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Request >>>'
go

/* 
 * TABLE: Role 
 */

CREATE TABLE Role(
    RoleId         uniqueidentifier    NOT NULL,
    Name           nvarchar(80)        NULL,
    Description    nvarchar(1000)      NULL,
    Created        int                 IDENTITY(1,1),
    CONSTRAINT PK101 PRIMARY KEY NONCLUSTERED (RoleId)
)
go



IF OBJECT_ID('Role') IS NOT NULL
    PRINT '<<< CREATED TABLE Role >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Role >>>'
go

/* 
 * TABLE: Sitting 
 */

CREATE TABLE Sitting(
    SittingId     uniqueidentifier    NOT NULL,
    ChairmanId    uniqueidentifier    NULL,
    Started       datetime            NULL,
    Finished      datetime            NULL,
    CONSTRAINT PK139 PRIMARY KEY NONCLUSTERED (SittingId)
)
go



IF OBJECT_ID('Sitting') IS NOT NULL
    PRINT '<<< CREATED TABLE Sitting >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Sitting >>>'
go

/* 
 * TABLE: SittingParticipant 
 */

CREATE TABLE SittingParticipant(
    SittingId           uniqueidentifier    NOT NULL,
    EconomicMemberId    uniqueidentifier    NOT NULL,
    Registered          bit                  DEFAULT 0 NOT NULL,
    CONSTRAINT PK153 PRIMARY KEY NONCLUSTERED (SittingId, EconomicMemberId)
)
go



IF OBJECT_ID('SittingParticipant') IS NOT NULL
    PRINT '<<< CREATED TABLE SittingParticipant >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE SittingParticipant >>>'
go

/* 
 * TABLE: SittingQuestion 
 */

CREATE TABLE SittingQuestion(
    ProcessId           uniqueidentifier    NOT NULL,
    SittingId           uniqueidentifier    NULL,
    Number              int                  DEFAULT 0 NOT NULL,
    QuestionText        ntext               NULL,
    QuestionDecision    ntext               NULL,
    Created             int                 IDENTITY(1,1),
    CONSTRAINT PK140 PRIMARY KEY NONCLUSTERED (ProcessId)
)
go



IF OBJECT_ID('SittingQuestion') IS NOT NULL
    PRINT '<<< CREATED TABLE SittingQuestion >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE SittingQuestion >>>'
go

/* 
 * TABLE: SRO 
 */

CREATE TABLE SRO(
    SROId                             uniqueidentifier    NOT NULL,
    RegistrationNumber                nvarchar(80)        NULL,
    RegistrationDate                  datetime            NULL,
    CompensationFund                  money               NULL,
    LegalPersonId                     uniqueidentifier    NOT NULL,
    LastChargeDate                    datetime            NULL,
    sroe_version                      nvarchar(100)       NULL,
    SROCouncilTill                    datetime            NULL,
    SROCouncilHeadTill                datetime            NULL,
    ContestCommitteeTill              datetime            NULL,
    ContestCommitteeHeadTill          datetime            NULL,
    AccreditationCommitteeTill        datetime            NULL,
    AccreditationCommitteeHeadTill    datetime            NULL,
    CheckingCommitteeTill             datetime            NULL,
    CheckingCommitteeHeadTill         datetime            NULL,
    DisciplinaryCommitteeTill         datetime            NULL,
    DisciplinaryCommitteeHeadTill     datetime            NULL,
    SROHeadAuthorityTill              datetime            NULL,
    CONSTRAINT PK138 PRIMARY KEY NONCLUSTERED (SROId)
)
go



IF OBJECT_ID('SRO') IS NOT NULL
    PRINT '<<< CREATED TABLE SRO >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE SRO >>>'
go

/* 
 * TABLE: SROMember 
 */

CREATE TABLE SROMember(
    SROMemberId            uniqueidentifier    NOT NULL,
    EconomicMemberId       uniqueidentifier    NOT NULL,
    SROId                  uniqueidentifier    NULL,
    Type                   char(1)             NULL,
    Number                 nvarchar(30)        NULL,
    EditedNumber           nvarchar(30)        NULL,
    Note                   ntext               NULL,
    StoppingReason         nvarchar(250)       NULL,
    StoppingDate           datetime            NULL,
    StoppingDJDate         datetime            NULL,
    Created                int                 IDENTITY(1,1),
    DateOn                 datetime            NULL,
    DateDJAnswer           datetime            NULL,
    State                  char(1)             NULL,
    UnregisteredPaidSum    money               NULL,
    CONSTRAINT PK108 PRIMARY KEY NONCLUSTERED (SROMemberId)
)
go



IF OBJECT_ID('SROMember') IS NOT NULL
    PRINT '<<< CREATED TABLE SROMember >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE SROMember >>>'
go

/* 
 * TABLE: TPassword 
 */

CREATE TABLE TPassword(
    TPasswordId    uniqueidentifier    NOT NULL,
    ePassword      nvarchar(50)        NOT NULL,
    CONSTRAINT PK137 PRIMARY KEY NONCLUSTERED (TPasswordId)
)
go



IF OBJECT_ID('TPassword') IS NOT NULL
    PRINT '<<< CREATED TABLE TPassword >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE TPassword >>>'
go

/* 
 * VIEW: AccreditedT 
 */

CREATE VIEW AccreditedT AS
SELECT SR.Type Type, SR.Note Note, Ac.AccreditedId AccreditedId, SR.SROMemberId SROMemberId, SR.EconomicMemberId EconomicMemberId, SR.Created Created, Ac.RegistrationCertificateNumber RegistrationCertificateNumber, Ac.DateTill DateTill, Ac.TariffPlan TariffPlan, Ac.RegistrationCertificateDate RegistrationCertificateDate, Ac.DocumentId DocumentId, SR.StoppingReason, SR.StoppingDate, Ac.IsInsurer, Ac.IsEquityMarketParticipant, SR.EditedNumber, SR.DateOn, SR.DateDJAnswer, Ac.KickbackPercent, SR.StoppingDJDate, SR.State, SR.UnregisteredPaidSum, SR.Number
FROM SROMember SR, Accredited Ac
WHERE Ac.AccreditedId = SR.SROMemberId
 AND Ac.AccreditedId = SR.SROMemberId AND Ac.AccreditedId = SR.SROMemberId
 AND Ac.AccreditedId = SR.SROMemberId
go

IF OBJECT_ID('AccreditedT') IS NOT NULL
    PRINT '<<< CREATED VIEW AccreditedT >>>'
ELSE
    PRINT '<<< FAILED CREATING VIEW AccreditedT >>>'
go

/* 
 * VIEW: AddressT 
 */

CREATE VIEW AddressT AS
SELECT Co.Note Note, Ad.ZipCode ZipCode, Ad.City City, Ad.AddressLine AddressLine, Ad.AddressId AddressId, Ad.ProvinceId ProvinceId, Co.ContactInfoId ContactInfoId, Co.ContactTypeId ContactTypeId, Co.EconomicMemberId EconomicMemberId, Co.IsPublic IsPublic, Co.Created
FROM ContactInfo Co, Address Ad
WHERE Ad.AddressId = Co.ContactInfoId
go

IF OBJECT_ID('AddressT') IS NOT NULL
    PRINT '<<< CREATED VIEW AddressT >>>'
ELSE
    PRINT '<<< FAILED CREATING VIEW AddressT >>>'
go

/* 
 * VIEW: AuditT 
 */

CREATE VIEW AuditT AS
SELECT St.Note Note, St.Type Type, Au.guilty guilty, Au.AuditId AuditId, Pr.BancruptcySubProcessId, Pr.ProcedureId ProcedureId, St.ProcessId, St.InitialDocumentId InitialDocumentId, St.FinalDocumentId FinalDocumentId, Au.Result, Au.DisciplineId DisciplineId, St.FinishDeadlineDate, St.Number, St.EditedNumber, St.InitialDocumentNumber, St.FinalDocumentNumber, St.InitialDocumentDate, St.FinalDocumentDate, St.State, St.ExecutorId, St.Created
FROM Process St, BancruptcySubProcess Pr, Audit Au
WHERE Au.AuditId = Pr.BancruptcySubProcessId
go

IF OBJECT_ID('AuditT') IS NOT NULL
    PRINT '<<< CREATED VIEW AuditT >>>'
ELSE
    PRINT '<<< FAILED CREATING VIEW AuditT >>>'
go

/* 
 * VIEW: ComplaintT 
 */

CREATE VIEW ComplaintT AS
SELECT St.Note Note, St.Type Type, Co.Audit audit, Co.ComplaintId ComplaintId, Pr.BancruptcySubProcessId, Pr.ProcedureId ProcedureId, St.ProcessId, St.InitialDocumentId InitialDocumentId, St.FinalDocumentId FinalDocumentId, Co.Answer Answer, Co.ShortContent ShortContent, Co.WasAbnormality WasAbnormality, Co.AuditId AuditId, St.FinishDeadlineDate, St.Number, St.EditedNumber, St.InitialDocumentNumber, St.FinalDocumentNumber, St.InitialDocumentDate, St.FinalDocumentDate, St.State, St.ExecutorId, St.Created
FROM Process St, BancruptcySubProcess Pr, Complaint Co
WHERE Pr.BancruptcySubProcessId = St.ProcessId AND Co.ComplaintId = Pr.BancruptcySubProcessId AND Co.ComplaintId = Pr.BancruptcySubProcessId
go

IF OBJECT_ID('ComplaintT') IS NOT NULL
    PRINT '<<< CREATED VIEW ComplaintT >>>'
ELSE
    PRINT '<<< FAILED CREATING VIEW ComplaintT >>>'
go

/* 
 * VIEW: DisciplineT 
 */

CREATE VIEW DisciplineT AS
SELECT Tor.DisciplineId, Tor.Result, Tor.ManagerId, St.ProcessId, St.InitialDocumentId InitialDocumentId, St.FinalDocumentId FinalDocumentId, St.Note Note, St.Type Type, St.FinishDeadlineDate, St.Number, St.EditedNumber, St.InitialDocumentNumber, St.FinalDocumentNumber, St.InitialDocumentDate, St.FinalDocumentDate, St.State, St.ExecutorId, St.Created
FROM Process St, Discipline Tor
WHERE Tor.DisciplineId = St.ProcessId
go

IF OBJECT_ID('DisciplineT') IS NOT NULL
    PRINT '<<< CREATED VIEW DisciplineT >>>'
ELSE
    PRINT '<<< FAILED CREATING VIEW DisciplineT >>>'
go

/* 
 * VIEW: DocumentAddressT 
 */

CREATE VIEW DocumentAddressT AS
SELECT Do.Name, Doc.ZipCode, Doc.City, Doc.AddressLine, Doc.Province, Doc.DocumentAddressId, Do.DocumentChannelId, Do.EconomicMemberId, Do.ContactTypeId, Do.IncomingId, Do.DocumentTargetId, Do.Created
FROM DocumentChannel Do, DocumentAddress Doc
WHERE Doc.DocumentAddressId = Do.DocumentChannelId
go

IF OBJECT_ID('DocumentAddressT') IS NOT NULL
    PRINT '<<< CREATED VIEW DocumentAddressT >>>'
ELSE
    PRINT '<<< FAILED CREATING VIEW DocumentAddressT >>>'
go

/* 
 * VIEW: ExecutorT 
 */

CREATE VIEW ExecutorT AS
SELECT Ex.Login, Ex.IsActive, TP.ePassword, Ex.NaturalPersonId, Ex.ExecutorId, TP.TPasswordId, Ex.Created, Ex.AppUserConfig
FROM Executor Ex, TPassword TP
go

IF OBJECT_ID('ExecutorT') IS NOT NULL
    PRINT '<<< CREATED VIEW ExecutorT >>>'
ELSE
    PRINT '<<< FAILED CREATING VIEW ExecutorT >>>'
go

/* 
 * VIEW: ExtraContactInfoT 
 */

CREATE VIEW ExtraContactInfoT AS
SELECT Co.Note Note, Ex.Contact Contact, Ex.ExtraContactInfoId ExtraContactInfoId, Co.ContactInfoId ContactInfoId, Co.ContactTypeId ContactTypeId, Co.EconomicMemberId EconomicMemberId, Co.IsPublic IsPublic, Co.Created
FROM ContactInfo Co, ExtraContactInfo Ex
WHERE Ex.ExtraContactInfoId = Co.ContactInfoId
go

IF OBJECT_ID('ExtraContactInfoT') IS NOT NULL
    PRINT '<<< CREATED VIEW ExtraContactInfoT >>>'
ELSE
    PRINT '<<< FAILED CREATING VIEW ExtraContactInfoT >>>'
go

/* 
 * VIEW: ExtraDocumentChannelT 
 */

CREATE VIEW ExtraDocumentChannelT AS
SELECT Do.Name, Ex.Contact, Ex.ExtraDocumentChannelId, Do.DocumentChannelId, Do.EconomicMemberId, Do.ContactTypeId, Do.IncomingId, Do.DocumentTargetId, Do.Created
FROM DocumentChannel Do, ExtraDocumentChannel Ex
WHERE Ex.ExtraDocumentChannelId = Do.DocumentChannelId
go

IF OBJECT_ID('ExtraDocumentChannelT') IS NOT NULL
    PRINT '<<< CREATED VIEW ExtraDocumentChannelT >>>'
ELSE
    PRINT '<<< FAILED CREATING VIEW ExtraDocumentChannelT >>>'
go

/* 
 * VIEW: FilialT 
 */

CREATE VIEW FilialT AS
SELECT SR.Type Type, SR.Note Note, Fi.FilialId FilialId, Fi.FilialType FilialType, SR.SROMemberId SROMemberId, SR.EconomicMemberId EconomicMemberId, SR.Created Created, SR.StoppingReason, SR.StoppingDate, SR.EditedNumber, SR.DateOn, SR.DateDJAnswer, SR.StoppingDJDate, SR.State, SR.UnregisteredPaidSum, Fi.HeadAuthorityTill, Fi.FoundationDate, Fi.FoundationReason, SR.Number
FROM SROMember SR, Filial Fi
WHERE Fi.FilialId = SR.SROMemberId
go

IF OBJECT_ID('FilialT') IS NOT NULL
    PRINT '<<< CREATED VIEW FilialT >>>'
ELSE
    PRINT '<<< FAILED CREATING VIEW FilialT >>>'
go

/* 
 * VIEW: IncomingT 
 */

CREATE VIEW IncomingT AS
SELECT Do.Type Type, Do.Action Action, Do.Title Title, Do.Number Number, Do.Content Content, Do.Note Note, Inc.OriginalNumber OriginalNumber, Inc.DateDispatched DateDispatched, Inc.DateReceived DateReceived, Inc.IncomingId IncomingId, Do.AuthorId AuthorId, Do.DocumentId DocumentId, Do.Created, Do.FileName, Do.DateInput, Do.EditedNumber, Inc.OriginalDate, Do.ShortContent, Do.Blocked, Do.Computer, Do.Revision, Do.EditorId
FROM Document Do, Incoming Inc
WHERE Inc.IncomingId = Do.DocumentId
 AND Inc.IncomingId = Do.DocumentId AND Inc.IncomingId = Do.DocumentId
go

IF OBJECT_ID('IncomingT') IS NOT NULL
    PRINT '<<< CREATED VIEW IncomingT >>>'
ELSE
    PRINT '<<< FAILED CREATING VIEW IncomingT >>>'
go

/* 
 * VIEW: LegalPersonT 
 */

CREATE VIEW LegalPersonT AS
SELECT Ec.EconomicMemberId EconomicMemberId, Ec.IndustryId IndustryId, Ec.OKFS OKFS, Ec.OKOPF OKOPF, Ec.Type Type, Ec.INN INN, Ec.Note Note, Ec.OKPO OKPO, Ec.OKVED OKVED, Le.LegalPersonId LegalPersonId, Le.Name Name, Le.ShortName ShortName, Le.KPP KPP, Le.OGRN OGRN, Le.Created Created, Ec.IsLegalPerson, Ec.IsManager, Ec.IsAccredited, Ec.IsFilial, Ec.IsExecutor, Ec.IsAlive, Ec.IsBank, Ec.IsContragent, Ec.RegistrationDate, Ec.RegistrationOrganization, Ec.Activity, Le.FixedCapital, Le.GovShareInFixedCapital, Ec.NumberOfEmployee, Ec.AverageWage, Ec.TaxRegistrationDate, Ec.RegistrationSertificateNumber, Ec.RegistrationSertificateSeries, Ec.EGRULExclusionNumber, Ec.EGRULExclusionDate
FROM EconomicMember Ec, LegalPerson Le
WHERE Le.LegalPersonId = Ec.EconomicMemberId
go

IF OBJECT_ID('LegalPersonT') IS NOT NULL
    PRINT '<<< CREATED VIEW LegalPersonT >>>'
ELSE
    PRINT '<<< FAILED CREATING VIEW LegalPersonT >>>'
go

/* 
 * VIEW: ManagerProcedureT 
 */

CREATE VIEW ManagerProcedureT AS
SELECT St.Note Note, St.Type Type, Ma.DateStart DateStart, Ma.ManagerProcedureId ManagerProcedureId, Pu.BancruptcyProcessId, Pu.DebtorId DebtorId, Pu.PreviousProcessId, Pu.CourtId CourtId, St.ProcessId, St.InitialDocumentId InitialDocumentId, St.FinalDocumentId FinalDocumentId, Pu.ProcedureType ProcedureType, Ma.ManagerId ManagerId, Pu.Fee Fee, Pu.DealNumber DealNumber, Ma.ExtraFinishReason ExtraFinishReason, Ma.ReportsMode ReportsMode, Pu.ApplicationDate ApplicationDate, Pu.ApplicantId ApplicantId, Ma.DateFinish DateFinish, Pu.DesignationDate DesignationDate, Pu.DealStartDate DealStartDate, Ma.InsuranceOrganization, Ma.InsuranceDate InsuranceDate, Ma.InsuranceDateTill InsuranceDateTill, Ma.InsuranceNumber InsuranceNumber, Ma.InsuranceSum InsuranceSum, Ma.PublicationDate PublicationDate, Ma.PublicationPlace PublicationPlace, Ma.PublicationReleaseNumber PublicationReleaseNumber, Ma.PublicationAdvertisementNumber PublicationAdvertisementNumber, Pu.DebtorType DebtorType, Pu.OrganizationType, St.FinishDeadlineDate, St.Number, St.EditedNumber, Ma.ReportDeadline, Ma.Rating, Ma.DateDebtorInfoReceived, St.InitialDocumentNumber, St.FinalDocumentNumber, St.InitialDocumentDate, St.FinalDocumentDate, Ma.DebtsDate, Ma.MainIndexDate1, Ma.MainIndexDate2, St.State, St.ExecutorId, St.Created, Ma.InsurancePoliceNumber
FROM Process St, BancruptcyProcess Pu, ManagerProcedure Ma
WHERE Pu.BancruptcyProcessId = St.ProcessId AND Ma.ManagerProcedureId = Pu.BancruptcyProcessId
 AND Pu.BancruptcyProcessId = St.ProcessId
go

IF OBJECT_ID('ManagerProcedureT') IS NOT NULL
    PRINT '<<< CREATED VIEW ManagerProcedureT >>>'
ELSE
    PRINT '<<< FAILED CREATING VIEW ManagerProcedureT >>>'
go

/* 
 * VIEW: ManagerT 
 */

CREATE VIEW ManagerT AS
SELECT SR.Type Type, SR.Note Note, Ma.RegisterNumber RegisterNumber, Ma.RegistrationCertificateDate RegistrationCertificateDate, Ma.RegistrationCertificateNumber RegistrationCertificateNumber, Ma.IsStrategicalManager IsStrategicalManager, Ma.TExamDate TExamDate, Ma.InsuranceNumber InsuranceNumber, Ma.InsuranceDate InsuranceDate, Ma.InsuranceOrganization, Ma.ManagerId ManagerId, Ma.FilialId FilialId, SR.SROMemberId SROMemberId, SR.EconomicMemberId EconomicMemberId, Ma.StateSecretAccessLevel StateSecretAccessLevel, SR.Created Created, Ma.ExtraProceduresCount ExtraProceduresCount, Ma.PsychologistResume PsychologistResume, Ma.InsuranceDateTill, Ma.InsuranceSum, Ma.TExamDiplomNumber, SR.StoppingReason, SR.StoppingDate, Ma.DateOfStart, SR.EditedNumber, SR.DateOn, SR.DateDJAnswer, Ma.IsNotConvictionTill, Ma.ChiefDuration, Ma.TExamDiplomSeries, SR.StoppingDJDate, SR.State, Ma.NotNominative, Ma.IsTransferedFromOtherSRO, SR.UnregisteredPaidSum, Ma.NotConvictionNumber, Ma.StateSecretReceivingDate, Ma.StateSecretEndDate, Ma.StateSecretOrganization, Ma.TEKSeriaNumber, Ma.TEKDate, Ma.TEKOrganization, Ma.CBNumber, Ma.CBDateTill, SR.Number, Ma.PPExamDiplomNumber, Ma.PPExamDiplomDate, Ma.PPExamVUZ, Ma.PPExamDescription, Ma.TExamDiplomDate, Ma.ProbationCertificateNumber, Ma.ProbationCertificateDate, Ma.ProbationCertificateOrganization, Ma.InsurancePoliceNumber
FROM SROMember SR, Manager Ma
WHERE Ma.ManagerId = SR.SROMemberId
go

IF OBJECT_ID('ManagerT') IS NOT NULL
    PRINT '<<< CREATED VIEW ManagerT >>>'
ELSE
    PRINT '<<< FAILED CREATING VIEW ManagerT >>>'
go

/* 
 * VIEW: NaturalPersonT 
 */

CREATE VIEW NaturalPersonT AS
SELECT Ec.EconomicMemberId EconomicMemberId, Ec.IndustryId IndustryId, Ec.OKFS OKFS, Ec.OKOPF OKOPF, Ec.Type Type, Ec.INN INN, Ec.OKPO OKPO, Ec.Note Note, Ec.OKVED OKVED, Na.NaturalPersonId NaturalPersonId, Na.FirstName FirstName, Na.MiddleName MiddleName, Na.LastName LastName, Na.OGRNIP OGRNIP, Na.PassportNumber PassportNumber, Na.PassportGiven PassportGiven, Na.PassportSeries PassportSeries, Na.Created Created, Na.NameNotes NameNotes, Na.BirthPlace BirthPlace, Na.BirthDate BirthDate, Na.Nationality Nationality, Na.Languages Languages, Na.AcademicDegrees AcademicDegrees, Na.Certificates Certificates, Na.PassportDate, Ec.IsLegalPerson, Ec.IsManager, Ec.IsAccredited, Ec.IsFilial, Ec.IsExecutor, Ec.IsAlive, Ec.IsBank, Ec.IsContragent, Ec.RegistrationDate, Ec.RegistrationOrganization, Ec.Activity, Ec.NumberOfEmployee, Ec.AverageWage, Ec.TaxRegistrationDate, Ec.RegistrationSertificateNumber, Ec.RegistrationSertificateSeries, Ec.EGRULExclusionNumber, Ec.EGRULExclusionDate
FROM NaturalPerson Na, EconomicMember Ec
go

IF OBJECT_ID('NaturalPersonT') IS NOT NULL
    PRINT '<<< CREATED VIEW NaturalPersonT >>>'
ELSE
    PRINT '<<< FAILED CREATING VIEW NaturalPersonT >>>'
go

/* 
 * VIEW: OfferT 
 */

CREATE VIEW OfferT AS
SELECT St.Note Note, St.Type Type, Offe.Position_in_final_list Position_in_final_list, Offe.agree agree, Offe.OfferId OfferId, Offe.RequestId RequestId, Offe.ManagerId ManagerId, St.ProcessId, St.InitialDocumentId InitialDocumentId, St.FinalDocumentId FinalDocumentId, St.FinishDeadlineDate, St.Number, St.EditedNumber, St.InitialDocumentNumber, St.FinalDocumentNumber, St.InitialDocumentDate, St.FinalDocumentDate, St.State, St.ExecutorId, St.Created
FROM Process St, Offer Offe
WHERE Offe.OfferId = St.ProcessId
go

IF OBJECT_ID('OfferT') IS NOT NULL
    PRINT '<<< CREATED VIEW OfferT >>>'
ELSE
    PRINT '<<< FAILED CREATING VIEW OfferT >>>'
go

/* 
 * VIEW: OutcomingT 
 */

CREATE VIEW OutcomingT AS
SELECT Do.Type, Do.Action Action, Do.Title Title, Do.Number Number, Do.Content Content, Do.Note Note, Ou.OutcomingId OutcomingId, Do.DocumentId DocumentId, Do.AuthorId AuthorId, Do.Created, Do.FileName, Do.DateInput, Do.EditedNumber, Do.ShortContent, Do.Blocked, Do.Computer, Do.Revision, Do.EditorId
FROM Document Do, Outcoming Ou
WHERE Ou.OutcomingId = Do.DocumentId
go

IF OBJECT_ID('OutcomingT') IS NOT NULL
    PRINT '<<< CREATED VIEW OutcomingT >>>'
ELSE
    PRINT '<<< FAILED CREATING VIEW OutcomingT >>>'
go

/* 
 * VIEW: ProcedureReportT 
 */

CREATE VIEW ProcedureReportT AS
SELECT St.Note Note, St.Type Type, Pro.Mark Mark, Pro.ProcedureReportId ProcedureReportId, Pro.ResponseDocumentId ResponseDocumentId, Pr.BancruptcySubProcessId, Pr.ProcedureId ProcedureId, St.ProcessId, St.InitialDocumentId InitialDocumentId, St.FinalDocumentId FinalDocumentId, Pro.WasAbnormality WasAbnormality, St.FinishDeadlineDate, Pro.StartDeadlineDate, St.Number, St.EditedNumber, Pro.WasLate, Pro.AnalyzeDescription, Pro.ExportedPackage, Pro.ExportedPackageModelVersion, St.InitialDocumentNumber, St.FinalDocumentNumber, St.InitialDocumentDate, St.FinalDocumentDate, St.State, St.ExecutorId, Pro.ReportType, St.Created
FROM Process St, BancruptcySubProcess Pr, ProcedureReport Pro
WHERE Pr.BancruptcySubProcessId = St.ProcessId AND Pro.ProcedureReportId = Pr.BancruptcySubProcessId
 AND Pro.ProcedureReportId = Pr.BancruptcySubProcessId
go

IF OBJECT_ID('ProcedureReportT') IS NOT NULL
    PRINT '<<< CREATED VIEW ProcedureReportT >>>'
ELSE
    PRINT '<<< FAILED CREATING VIEW ProcedureReportT >>>'
go

/* 
 * VIEW: RequestT 
 */

CREATE VIEW RequestT AS
SELECT St.Note Note, St.Type Type, Re.RequestId RequestId, Pu.BancruptcyProcessId, Pu.PreviousProcessId, Pu.DebtorId DebtorId, Pu.CourtId CourtId, St.ProcessId, St.InitialDocumentId InitialDocumentId, St.FinalDocumentId FinalDocumentId, Pu.ProcedureType ProcedureType, Pu.Fee Fee, Pu.DealNumber DealNumber, Pu.ApplicationDate ApplicationDate, Pu.ApplicantId ApplicantId, Pu.DesignationDate DesignationDate, Pu.DealStartDate DealStartDate, Pu.DebtorType DebtorType, Pu.OrganizationType, Re.ExtraRequirements ExtraRequirements, St.FinishDeadlineDate, Re.DecisionNumber, Re.DecisionDate, St.Number, St.EditedNumber, St.InitialDocumentNumber, St.FinalDocumentNumber, St.InitialDocumentDate, St.FinalDocumentDate, St.State, St.ExecutorId, St.Created
FROM Process St, BancruptcyProcess Pu, Request Re
WHERE Pu.BancruptcyProcessId = St.ProcessId AND Re.RequestId = Pu.BancruptcyProcessId AND Pu.BancruptcyProcessId = St.ProcessId
go

IF OBJECT_ID('RequestT') IS NOT NULL
    PRINT '<<< CREATED VIEW RequestT >>>'
ELSE
    PRINT '<<< FAILED CREATING VIEW RequestT >>>'
go

/* 
 * VIEW: SittingT 
 */

CREATE VIEW SittingT AS
SELECT St.Note, St.Type, St.FinishDeadlineDate, Si.Started, Si.Finished, Si.SittingId, Si.ChairmanId, St.ProcessId, St.InitialDocumentId, St.FinalDocumentId, St.Number, St.EditedNumber, St.InitialDocumentNumber, St.FinalDocumentNumber, St.InitialDocumentDate, St.FinalDocumentDate, St.State, St.ExecutorId, St.Created
FROM Process St, Sitting Si
WHERE Si.SittingId = St.ProcessId
go

IF OBJECT_ID('SittingT') IS NOT NULL
    PRINT '<<< CREATED VIEW SittingT >>>'
ELSE
    PRINT '<<< FAILED CREATING VIEW SittingT >>>'
go

/* 
 * INDEX: Ref19317 
 */

CREATE INDEX Ref19317 ON Accreditation(AccreditedId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Accreditation') AND name='Ref19317')
    PRINT '<<< CREATED INDEX Accreditation.Ref19317 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Accreditation.Ref19317 >>>'
go

/* 
 * INDEX: Ref72321 
 */

CREATE INDEX Ref72321 ON Accreditation(DocumentId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Accreditation') AND name='Ref72321')
    PRINT '<<< CREATED INDEX Accreditation.Ref72321 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Accreditation.Ref72321 >>>'
go

/* 
 * INDEX: Ref132284 
 */

CREATE INDEX Ref132284 ON Accreditation_Line(LineOfAccreditationId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Accreditation_Line') AND name='Ref132284')
    PRINT '<<< CREATED INDEX Accreditation_Line.Ref132284 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Accreditation_Line.Ref132284 >>>'
go

/* 
 * INDEX: Ref150320 
 */

CREATE INDEX Ref150320 ON Accreditation_Line(AccreditationId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Accreditation_Line') AND name='Ref150320')
    PRINT '<<< CREATED INDEX Accreditation_Line.Ref150320 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Accreditation_Line.Ref150320 >>>'
go

/* 
 * INDEX: Ref150319 
 */

CREATE INDEX Ref150319 ON Accreditation_Province(AccreditationId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Accreditation_Province') AND name='Ref150319')
    PRINT '<<< CREATED INDEX Accreditation_Province.Ref150319 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Accreditation_Province.Ref150319 >>>'
go

/* 
 * INDEX: Ref127318 
 */

CREATE INDEX Ref127318 ON Accreditation_Province(ProvinceId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Accreditation_Province') AND name='Ref127318')
    PRINT '<<< CREATED INDEX Accreditation_Province.Ref127318 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Accreditation_Province.Ref127318 >>>'
go

/* 
 * INDEX: IsInsurer 
 */

CREATE INDEX IsInsurer ON Accredited(IsInsurer)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Accredited') AND name='IsInsurer')
    PRINT '<<< CREATED INDEX Accredited.IsInsurer >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Accredited.IsInsurer >>>'
go

/* 
 * INDEX: IsEquityMarketParticipant 
 */

CREATE INDEX IsEquityMarketParticipant ON Accredited(IsEquityMarketParticipant)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Accredited') AND name='IsEquityMarketParticipant')
    PRINT '<<< CREATED INDEX Accredited.IsEquityMarketParticipant >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Accredited.IsEquityMarketParticipant >>>'
go

/* 
 * INDEX: DateTill 
 */

CREATE INDEX DateTill ON Accredited(DateTill)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Accredited') AND name='DateTill')
    PRINT '<<< CREATED INDEX Accredited.DateTill >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Accredited.DateTill >>>'
go

/* 
 * INDEX: Ref108145 
 */

CREATE INDEX Ref108145 ON Accredited(AccreditedId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Accredited') AND name='Ref108145')
    PRINT '<<< CREATED INDEX Accredited.Ref108145 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Accredited.Ref108145 >>>'
go

/* 
 * INDEX: Ref72271 
 */

CREATE INDEX Ref72271 ON Accredited(DocumentId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Accredited') AND name='Ref72271')
    PRINT '<<< CREATED INDEX Accredited.Ref72271 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Accredited.Ref72271 >>>'
go

/* 
 * INDEX: Ref125236 
 */

CREATE INDEX Ref125236 ON Address(AddressId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Address') AND name='Ref125236')
    PRINT '<<< CREATED INDEX Address.Ref125236 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Address.Ref125236 >>>'
go

/* 
 * INDEX: Ref127245 
 */

CREATE INDEX Ref127245 ON Address(ProvinceId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Address') AND name='Ref127245')
    PRINT '<<< CREATED INDEX Address.Ref127245 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Address.Ref127245 >>>'
go

/* 
 * INDEX: Ref7307 
 */

CREATE INDEX Ref7307 ON AssetChange(ManagerProcedureId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('AssetChange') AND name='Ref7307')
    PRINT '<<< CREATED INDEX AssetChange.Ref7307 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX AssetChange.Ref7307 >>>'
go

/* 
 * INDEX: Ref106308 
 */

CREATE INDEX Ref106308 ON AssetChange(EconomicMemberId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('AssetChange') AND name='Ref106308')
    PRINT '<<< CREATED INDEX AssetChange.Ref106308 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX AssetChange.Ref106308 >>>'
go

/* 
 * INDEX: Ref72120 
 */

CREATE INDEX Ref72120 ON Attachment(DocumentId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Attachment') AND name='Ref72120')
    PRINT '<<< CREATED INDEX Attachment.Ref72120 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Attachment.Ref72120 >>>'
go

/* 
 * INDEX: Ref112274 
 */

CREATE INDEX Ref112274 ON Attachment(OutcomingId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Attachment') AND name='Ref112274')
    PRINT '<<< CREATED INDEX Attachment.Ref112274 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Attachment.Ref112274 >>>'
go

/* 
 * INDEX: Ref117288 
 */

CREATE INDEX Ref117288 ON Audit(DisciplineId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Audit') AND name='Ref117288')
    PRINT '<<< CREATED INDEX Audit.Ref117288 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Audit.Ref117288 >>>'
go

/* 
 * INDEX: Ref115168 
 */

CREATE INDEX Ref115168 ON Audit(AuditId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Audit') AND name='Ref115168')
    PRINT '<<< CREATED INDEX Audit.Ref115168 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Audit.Ref115168 >>>'
go

/* 
 * INDEX: Ref121198 
 */

CREATE INDEX Ref121198 ON BancruptcyProcess(PreviousProcessId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('BancruptcyProcess') AND name='Ref121198')
    PRINT '<<< CREATED INDEX BancruptcyProcess.Ref121198 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX BancruptcyProcess.Ref121198 >>>'
go

/* 
 * INDEX: Ref122202 
 */

CREATE INDEX Ref122202 ON BancruptcyProcess(BancruptcyProcessId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('BancruptcyProcess') AND name='Ref122202')
    PRINT '<<< CREATED INDEX BancruptcyProcess.Ref122202 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX BancruptcyProcess.Ref122202 >>>'
go

/* 
 * INDEX: Ref106225 
 */

CREATE INDEX Ref106225 ON BancruptcyProcess(CourtId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('BancruptcyProcess') AND name='Ref106225')
    PRINT '<<< CREATED INDEX BancruptcyProcess.Ref106225 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX BancruptcyProcess.Ref106225 >>>'
go

/* 
 * INDEX: Ref106227 
 */

CREATE INDEX Ref106227 ON BancruptcyProcess(DebtorId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('BancruptcyProcess') AND name='Ref106227')
    PRINT '<<< CREATED INDEX BancruptcyProcess.Ref106227 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX BancruptcyProcess.Ref106227 >>>'
go

/* 
 * INDEX: Ref106257 
 */

CREATE INDEX Ref106257 ON BancruptcyProcess(ApplicantId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('BancruptcyProcess') AND name='Ref106257')
    PRINT '<<< CREATED INDEX BancruptcyProcess.Ref106257 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX BancruptcyProcess.Ref106257 >>>'
go

/* 
 * INDEX: Ref122204 
 */

CREATE INDEX Ref122204 ON BancruptcySubProcess(BancruptcySubProcessId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('BancruptcySubProcess') AND name='Ref122204')
    PRINT '<<< CREATED INDEX BancruptcySubProcess.Ref122204 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX BancruptcySubProcess.Ref122204 >>>'
go

/* 
 * INDEX: Ref7180 
 */

CREATE INDEX Ref7180 ON BancruptcySubProcess(ProcedureId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('BancruptcySubProcess') AND name='Ref7180')
    PRINT '<<< CREATED INDEX BancruptcySubProcess.Ref7180 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX BancruptcySubProcess.Ref7180 >>>'
go

/* 
 * INDEX: Ref105243 
 */

CREATE INDEX Ref105243 ON Bank(LegalPersonId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Bank') AND name='Ref105243')
    PRINT '<<< CREATED INDEX Bank.Ref105243 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Bank.Ref105243 >>>'
go

/* 
 * INDEX: Ref124231 
 */

CREATE INDEX Ref124231 ON BankAccount(BankId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('BankAccount') AND name='Ref124231')
    PRINT '<<< CREATED INDEX BankAccount.Ref124231 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX BankAccount.Ref124231 >>>'
go

/* 
 * INDEX: Ref106244 
 */

CREATE INDEX Ref106244 ON BankAccount(EconomicMemberId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('BankAccount') AND name='Ref106244')
    PRINT '<<< CREATED INDEX BankAccount.Ref106244 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX BankAccount.Ref106244 >>>'
go

/* 
 * INDEX: Ref106208 
 */

CREATE INDEX Ref106208 ON Comission(EconomicMemberId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Comission') AND name='Ref106208')
    PRINT '<<< CREATED INDEX Comission.Ref106208 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Comission.Ref106208 >>>'
go

/* 
 * INDEX: Ref140299 
 */

CREATE INDEX Ref140299 ON Comission(ProcessId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Comission') AND name='Ref140299')
    PRINT '<<< CREATED INDEX Comission.Ref140299 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Comission.Ref140299 >>>'
go

/* 
 * INDEX: Ref113287 
 */

CREATE INDEX Ref113287 ON Complaint(AuditId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Complaint') AND name='Ref113287')
    PRINT '<<< CREATED INDEX Complaint.Ref113287 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Complaint.Ref113287 >>>'
go

/* 
 * INDEX: Ref115167 
 */

CREATE INDEX Ref115167 ON Complaint(ComplaintId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Complaint') AND name='Ref115167')
    PRINT '<<< CREATED INDEX Complaint.Ref115167 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Complaint.Ref115167 >>>'
go

/* 
 * INDEX: Ref4239 
 */

CREATE INDEX Ref4239 ON ContactInfo(ContactTypeId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('ContactInfo') AND name='Ref4239')
    PRINT '<<< CREATED INDEX ContactInfo.Ref4239 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX ContactInfo.Ref4239 >>>'
go

/* 
 * INDEX: Ref106240 
 */

CREATE INDEX Ref106240 ON ContactInfo(EconomicMemberId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('ContactInfo') AND name='Ref106240')
    PRINT '<<< CREATED INDEX ContactInfo.Ref106240 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX ContactInfo.Ref106240 >>>'
go

/* 
 * INDEX: Ref118249 
 */

CREATE INDEX Ref118249 ON Deal(ProcedureReportId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Deal') AND name='Ref118249')
    PRINT '<<< CREATED INDEX Deal.Ref118249 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Deal.Ref118249 >>>'
go

/* 
 * INDEX: Ref7262 
 */

CREATE INDEX Ref7262 ON Deal(ManagerProcedureId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Deal') AND name='Ref7262')
    PRINT '<<< CREATED INDEX Deal.Ref7262 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Deal.Ref7262 >>>'
go

/* 
 * INDEX: Ref106266 
 */

CREATE INDEX Ref106266 ON Deal(EconomicMemberId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Deal') AND name='Ref106266')
    PRINT '<<< CREATED INDEX Deal.Ref106266 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Deal.Ref106266 >>>'
go

/* 
 * INDEX: Ref7305 
 */

CREATE INDEX Ref7305 ON DealPlan(ManagerProcedureId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('DealPlan') AND name='Ref7305')
    PRINT '<<< CREATED INDEX DealPlan.Ref7305 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX DealPlan.Ref7305 >>>'
go

/* 
 * INDEX: Ref106306 
 */

CREATE INDEX Ref106306 ON DealPlan(EconomicMemberId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('DealPlan') AND name='Ref106306')
    PRINT '<<< CREATED INDEX DealPlan.Ref106306 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX DealPlan.Ref106306 >>>'
go

/* 
 * INDEX: Ref122290 
 */

CREATE INDEX Ref122290 ON Discipline(DisciplineId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Discipline') AND name='Ref122290')
    PRINT '<<< CREATED INDEX Discipline.Ref122290 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Discipline.Ref122290 >>>'
go

/* 
 * INDEX: Ref1291 
 */

CREATE INDEX Ref1291 ON Discipline(ManagerId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Discipline') AND name='Ref1291')
    PRINT '<<< CREATED INDEX Discipline.Ref1291 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Discipline.Ref1291 >>>'
go

/* 
 * INDEX: Type 
 */

CREATE INDEX Type ON Document(Type)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Document') AND name='Type')
    PRINT '<<< CREATED INDEX Document.Type >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Document.Type >>>'
go

/* 
 * INDEX: Ref123217 
 */

CREATE INDEX Ref123217 ON Document(AuthorId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Document') AND name='Ref123217')
    PRINT '<<< CREATED INDEX Document.Ref123217 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Document.Ref123217 >>>'
go

/* 
 * INDEX: Ref123334 
 */

CREATE INDEX Ref123334 ON Document(EditorId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Document') AND name='Ref123334')
    PRINT '<<< CREATED INDEX Document.Ref123334 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Document.Ref123334 >>>'
go

/* 
 * INDEX: Ref133278 
 */

CREATE INDEX Ref133278 ON DocumentAddress(DocumentAddressId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('DocumentAddress') AND name='Ref133278')
    PRINT '<<< CREATED INDEX DocumentAddress.Ref133278 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX DocumentAddress.Ref133278 >>>'
go

/* 
 * INDEX: Ref4275 
 */

CREATE INDEX Ref4275 ON DocumentChannel(ContactTypeId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('DocumentChannel') AND name='Ref4275')
    PRINT '<<< CREATED INDEX DocumentChannel.Ref4275 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX DocumentChannel.Ref4275 >>>'
go

/* 
 * INDEX: Ref106279 
 */

CREATE INDEX Ref106279 ON DocumentChannel(EconomicMemberId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('DocumentChannel') AND name='Ref106279')
    PRINT '<<< CREATED INDEX DocumentChannel.Ref106279 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX DocumentChannel.Ref106279 >>>'
go

/* 
 * INDEX: Ref111282 
 */

CREATE INDEX Ref111282 ON DocumentChannel(IncomingId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('DocumentChannel') AND name='Ref111282')
    PRINT '<<< CREATED INDEX DocumentChannel.Ref111282 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX DocumentChannel.Ref111282 >>>'
go

/* 
 * INDEX: Ref126283 
 */

CREATE INDEX Ref126283 ON DocumentChannel(DocumentTargetId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('DocumentChannel') AND name='Ref126283')
    PRINT '<<< CREATED INDEX DocumentChannel.Ref126283 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX DocumentChannel.Ref126283 >>>'
go

/* 
 * INDEX: Ref123246 
 */

CREATE INDEX Ref123246 ON DocumentTarget(SenderId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('DocumentTarget') AND name='Ref123246')
    PRINT '<<< CREATED INDEX DocumentTarget.Ref123246 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX DocumentTarget.Ref123246 >>>'
go

/* 
 * INDEX: Ref123247 
 */

CREATE INDEX Ref123247 ON DocumentTarget(ConfirmatorId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('DocumentTarget') AND name='Ref123247')
    PRINT '<<< CREATED INDEX DocumentTarget.Ref123247 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX DocumentTarget.Ref123247 >>>'
go

/* 
 * INDEX: Ref123286 
 */

CREATE INDEX Ref123286 ON DocumentTarget(AuthorId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('DocumentTarget') AND name='Ref123286')
    PRINT '<<< CREATED INDEX DocumentTarget.Ref123286 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX DocumentTarget.Ref123286 >>>'
go

/* 
 * INDEX: Ref123337 
 */

CREATE INDEX Ref123337 ON DocumentTarget(PackerId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('DocumentTarget') AND name='Ref123337')
    PRINT '<<< CREATED INDEX DocumentTarget.Ref123337 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX DocumentTarget.Ref123337 >>>'
go

/* 
 * INDEX: Ref123338 
 */

CREATE INDEX Ref123338 ON DocumentTarget(PublisherId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('DocumentTarget') AND name='Ref123338')
    PRINT '<<< CREATED INDEX DocumentTarget.Ref123338 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX DocumentTarget.Ref123338 >>>'
go

/* 
 * INDEX: Ref112242 
 */

CREATE INDEX Ref112242 ON DocumentTarget(OutcomingId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('DocumentTarget') AND name='Ref112242')
    PRINT '<<< CREATED INDEX DocumentTarget.Ref112242 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX DocumentTarget.Ref112242 >>>'
go

/* 
 * INDEX: Ref129254 
 */

CREATE INDEX Ref129254 ON DocumentTarget(PostRegisterId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('DocumentTarget') AND name='Ref129254')
    PRINT '<<< CREATED INDEX DocumentTarget.Ref129254 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX DocumentTarget.Ref129254 >>>'
go

/* 
 * INDEX: IsManager 
 */

CREATE INDEX IsManager ON EconomicMember(IsManager)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('EconomicMember') AND name='IsManager')
    PRINT '<<< CREATED INDEX EconomicMember.IsManager >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX EconomicMember.IsManager >>>'
go

/* 
 * INDEX: IsAccredited 
 */

CREATE INDEX IsAccredited ON EconomicMember(IsAccredited)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('EconomicMember') AND name='IsAccredited')
    PRINT '<<< CREATED INDEX EconomicMember.IsAccredited >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX EconomicMember.IsAccredited >>>'
go

/* 
 * INDEX: Type 
 */

CREATE INDEX Type ON EconomicMember(Type)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('EconomicMember') AND name='Type')
    PRINT '<<< CREATED INDEX EconomicMember.Type >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX EconomicMember.Type >>>'
go

/* 
 * INDEX: Ref93226 
 */

CREATE INDEX Ref93226 ON EconomicMember(IndustryId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('EconomicMember') AND name='Ref93226')
    PRINT '<<< CREATED INDEX EconomicMember.Ref93226 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX EconomicMember.Ref93226 >>>'
go

/* 
 * INDEX: EconomicMember_OwnershipForm 
 */

CREATE INDEX EconomicMember_OwnershipForm ON EconomicMember(OKFS)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('EconomicMember') AND name='EconomicMember_OwnershipForm')
    PRINT '<<< CREATED INDEX EconomicMember.EconomicMember_OwnershipForm >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX EconomicMember.EconomicMember_OwnershipForm >>>'
go

/* 
 * INDEX: EconomicMember_OrganizationForm 
 */

CREATE INDEX EconomicMember_OrganizationForm ON EconomicMember(OKOPF)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('EconomicMember') AND name='EconomicMember_OrganizationForm')
    PRINT '<<< CREATED INDEX EconomicMember.EconomicMember_OrganizationForm >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX EconomicMember.EconomicMember_OrganizationForm >>>'
go

/* 
 * INDEX: Ref7310 
 */

CREATE INDEX Ref7310 ON EconomicVariableSnapShot(ManagerProcedureId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('EconomicVariableSnapShot') AND name='Ref7310')
    PRINT '<<< CREATED INDEX EconomicVariableSnapShot.Ref7310 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX EconomicVariableSnapShot.Ref7310 >>>'
go

/* 
 * INDEX: Ref145311 
 */

CREATE INDEX Ref145311 ON EconomicVariableSnapShot(EconomicVariableTypeId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('EconomicVariableSnapShot') AND name='Ref145311')
    PRINT '<<< CREATED INDEX EconomicVariableSnapShot.Ref145311 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX EconomicVariableSnapShot.Ref145311 >>>'
go

/* 
 * INDEX: Ref1104 
 */

CREATE INDEX Ref1104 ON Education(ManagerId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Education') AND name='Ref1104')
    PRINT '<<< CREATED INDEX Education.Ref1104 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Education.Ref1104 >>>'
go

/* 
 * INDEX: Ref105259 
 */

CREATE INDEX Ref105259 ON Employee(LegalPersonId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Employee') AND name='Ref105259')
    PRINT '<<< CREATED INDEX Employee.Ref105259 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Employee.Ref105259 >>>'
go

/* 
 * INDEX: Ref104260 
 */

CREATE INDEX Ref104260 ON Employee(NaturalPersonId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Employee') AND name='Ref104260')
    PRINT '<<< CREATED INDEX Employee.Ref104260 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Employee.Ref104260 >>>'
go

/* 
 * INDEX: Ref131261 
 */

CREATE INDEX Ref131261 ON Employee(EmployeePositionTypeId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Employee') AND name='Ref131261')
    PRINT '<<< CREATED INDEX Employee.Ref131261 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Employee.Ref131261 >>>'
go

/* 
 * INDEX: Ref104216 
 */

CREATE INDEX Ref104216 ON Executor(NaturalPersonId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Executor') AND name='Ref104216')
    PRINT '<<< CREATED INDEX Executor.Ref104216 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Executor.Ref104216 >>>'
go

/* 
 * INDEX: Ref101126 
 */

CREATE INDEX Ref101126 ON Executor_role(RoleId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Executor_role') AND name='Ref101126')
    PRINT '<<< CREATED INDEX Executor_role.Ref101126 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Executor_role.Ref101126 >>>'
go

/* 
 * INDEX: Ref123214 
 */

CREATE INDEX Ref123214 ON Executor_role(ExecutorId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Executor_role') AND name='Ref123214')
    PRINT '<<< CREATED INDEX Executor_role.Ref123214 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Executor_role.Ref123214 >>>'
go

/* 
 * INDEX: Ref1105 
 */

CREATE INDEX Ref1105 ON Experience(ManagerId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Experience') AND name='Ref1105')
    PRINT '<<< CREATED INDEX Experience.Ref1105 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Experience.Ref1105 >>>'
go

/* 
 * INDEX: Ref93114 
 */

CREATE INDEX Ref93114 ON Experience(IndustryId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Experience') AND name='Ref93114')
    PRINT '<<< CREATED INDEX Experience.Ref93114 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Experience.Ref93114 >>>'
go

/* 
 * INDEX: Ref106258 
 */

CREATE INDEX Ref106258 ON Experience(EconomicMemberId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Experience') AND name='Ref106258')
    PRINT '<<< CREATED INDEX Experience.Ref106258 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Experience.Ref106258 >>>'
go

/* 
 * INDEX: Ref91112 
 */

CREATE INDEX Ref91112 ON ExtensionField(ExtensionFieldTypeId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('ExtensionField') AND name='Ref91112')
    PRINT '<<< CREATED INDEX ExtensionField.Ref91112 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX ExtensionField.Ref91112 >>>'
go

/* 
 * INDEX: Ref108148 
 */

CREATE INDEX Ref108148 ON ExtensionField(SROMemberId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('ExtensionField') AND name='Ref108148')
    PRINT '<<< CREATED INDEX ExtensionField.Ref108148 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX ExtensionField.Ref108148 >>>'
go

/* 
 * INDEX: Ref125237 
 */

CREATE INDEX Ref125237 ON ExtraContactInfo(ExtraContactInfoId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('ExtraContactInfo') AND name='Ref125237')
    PRINT '<<< CREATED INDEX ExtraContactInfo.Ref125237 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX ExtraContactInfo.Ref125237 >>>'
go

/* 
 * INDEX: Ref133276 
 */

CREATE INDEX Ref133276 ON ExtraDocumentChannel(ExtraDocumentChannelId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('ExtraDocumentChannel') AND name='Ref133276')
    PRINT '<<< CREATED INDEX ExtraDocumentChannel.Ref133276 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX ExtraDocumentChannel.Ref133276 >>>'
go

/* 
 * INDEX: Ref122250 
 */

CREATE INDEX Ref122250 ON ExtraDocumentRequest(ProcessId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('ExtraDocumentRequest') AND name='Ref122250')
    PRINT '<<< CREATED INDEX ExtraDocumentRequest.Ref122250 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX ExtraDocumentRequest.Ref122250 >>>'
go

/* 
 * INDEX: Ref112251 
 */

CREATE INDEX Ref112251 ON ExtraDocumentRequest(OutcomingId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('ExtraDocumentRequest') AND name='Ref112251')
    PRINT '<<< CREATED INDEX ExtraDocumentRequest.Ref112251 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX ExtraDocumentRequest.Ref112251 >>>'
go

/* 
 * INDEX: Ref111252 
 */

CREATE INDEX Ref111252 ON ExtraDocumentRequest(IncomingId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('ExtraDocumentRequest') AND name='Ref111252')
    PRINT '<<< CREATED INDEX ExtraDocumentRequest.Ref111252 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX ExtraDocumentRequest.Ref111252 >>>'
go

/* 
 * INDEX: Ref108207 
 */

CREATE INDEX Ref108207 ON Filial(FilialId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Filial') AND name='Ref108207')
    PRINT '<<< CREATED INDEX Filial.Ref108207 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Filial.Ref108207 >>>'
go

/* 
 * INDEX: Ref72156 
 */

CREATE INDEX Ref72156 ON Incoming(IncomingId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Incoming') AND name='Ref72156')
    PRINT '<<< CREATED INDEX Incoming.Ref72156 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Incoming.Ref72156 >>>'
go

/* 
 * INDEX: Ref106129 
 */

CREATE INDEX Ref106129 ON LegalPerson(LegalPersonId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('LegalPerson') AND name='Ref106129')
    PRINT '<<< CREATED INDEX LegalPerson.Ref106129 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX LegalPerson.Ref106129 >>>'
go

/* 
 * INDEX: Ref108144 
 */

CREATE INDEX Ref108144 ON Manager(ManagerId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Manager') AND name='Ref108144')
    PRINT '<<< CREATED INDEX Manager.Ref108144 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Manager.Ref108144 >>>'
go

/* 
 * INDEX: Ref5498 
 */

CREATE INDEX Ref5498 ON Manager(FilialId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Manager') AND name='Ref5498')
    PRINT '<<< CREATED INDEX Manager.Ref5498 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Manager.Ref5498 >>>'
go

/* 
 * INDEX: Ref121193 
 */

CREATE INDEX Ref121193 ON ManagerProcedure(ManagerProcedureId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('ManagerProcedure') AND name='Ref121193')
    PRINT '<<< CREATED INDEX ManagerProcedure.Ref121193 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX ManagerProcedure.Ref121193 >>>'
go

/* 
 * INDEX: Ref123 
 */

CREATE INDEX Ref123 ON ManagerProcedure(ManagerId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('ManagerProcedure') AND name='Ref123')
    PRINT '<<< CREATED INDEX ManagerProcedure.Ref123 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX ManagerProcedure.Ref123 >>>'
go

/* 
 * INDEX: Ref72206 
 */

CREATE INDEX Ref72206 ON MembershipEvent(DocumentId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('MembershipEvent') AND name='Ref72206')
    PRINT '<<< CREATED INDEX MembershipEvent.Ref72206 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX MembershipEvent.Ref72206 >>>'
go

/* 
 * INDEX: Ref108149 
 */

CREATE INDEX Ref108149 ON MembershipEvent(SROMemberId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('MembershipEvent') AND name='Ref108149')
    PRINT '<<< CREATED INDEX MembershipEvent.Ref108149 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX MembershipEvent.Ref108149 >>>'
go

/* 
 * INDEX: Ref123325 
 */

CREATE INDEX Ref123325 ON MembershipEvent(ExecutorId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('MembershipEvent') AND name='Ref123325')
    PRINT '<<< CREATED INDEX MembershipEvent.Ref123325 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX MembershipEvent.Ref123325 >>>'
go

/* 
 * INDEX: Ref106128 
 */

CREATE INDEX Ref106128 ON NaturalPerson(NaturalPersonId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('NaturalPerson') AND name='Ref106128')
    PRINT '<<< CREATED INDEX NaturalPerson.Ref106128 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX NaturalPerson.Ref106128 >>>'
go

/* 
 * INDEX: Ref1186 
 */

CREATE INDEX Ref1186 ON Offer(ManagerId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Offer') AND name='Ref1186')
    PRINT '<<< CREATED INDEX Offer.Ref1186 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Offer.Ref1186 >>>'
go

/* 
 * INDEX: Ref119187 
 */

CREATE INDEX Ref119187 ON Offer(RequestId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Offer') AND name='Ref119187')
    PRINT '<<< CREATED INDEX Offer.Ref119187 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Offer.Ref119187 >>>'
go

/* 
 * INDEX: Ref122203 
 */

CREATE INDEX Ref122203 ON Offer(OfferId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Offer') AND name='Ref122203')
    PRINT '<<< CREATED INDEX Offer.Ref122203 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Offer.Ref122203 >>>'
go

/* 
 * INDEX: Ref72157 
 */

CREATE INDEX Ref72157 ON Outcoming(OutcomingId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Outcoming') AND name='Ref72157')
    PRINT '<<< CREATED INDEX Outcoming.Ref72157 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Outcoming.Ref72157 >>>'
go

/* 
 * INDEX: PaymentType 
 */

CREATE INDEX PaymentType ON Payment(PaymentType)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Payment') AND name='PaymentType')
    PRINT '<<< CREATED INDEX Payment.PaymentType >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Payment.PaymentType >>>'
go

/* 
 * INDEX: Ref147312 
 */

CREATE INDEX Ref147312 ON Payment(PaymentCategoryId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Payment') AND name='Ref147312')
    PRINT '<<< CREATED INDEX Payment.Ref147312 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Payment.Ref147312 >>>'
go

/* 
 * INDEX: Ref108152 
 */

CREATE INDEX Ref108152 ON Payment(SROMemberId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Payment') AND name='Ref108152')
    PRINT '<<< CREATED INDEX Payment.Ref108152 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Payment.Ref108152 >>>'
go

/* 
 * INDEX: Ref71328 
 */

CREATE INDEX Ref71328 ON Payment(DealId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Payment') AND name='Ref71328')
    PRINT '<<< CREATED INDEX Payment.Ref71328 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Payment.Ref71328 >>>'
go

/* 
 * INDEX: Ref7327 
 */

CREATE INDEX Ref7327 ON Payment(ManagerProcedureId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Payment') AND name='Ref7327')
    PRINT '<<< CREATED INDEX Payment.Ref7327 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Payment.Ref7327 >>>'
go

/* 
 * INDEX: Ref72253 
 */

CREATE INDEX Ref72253 ON PostRegister(DocumentId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('PostRegister') AND name='Ref72253')
    PRINT '<<< CREATED INDEX PostRegister.Ref72253 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX PostRegister.Ref72253 >>>'
go

/* 
 * INDEX: Ref123255 
 */

CREATE INDEX Ref123255 ON PostRegister(ExecutorId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('PostRegister') AND name='Ref123255')
    PRINT '<<< CREATED INDEX PostRegister.Ref123255 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX PostRegister.Ref123255 >>>'
go

/* 
 * INDEX: Ref72181 
 */

CREATE INDEX Ref72181 ON ProcedureReport(ResponseDocumentId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('ProcedureReport') AND name='Ref72181')
    PRINT '<<< CREATED INDEX ProcedureReport.Ref72181 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX ProcedureReport.Ref72181 >>>'
go

/* 
 * INDEX: Ref115179 
 */

CREATE INDEX Ref115179 ON ProcedureReport(ProcedureReportId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('ProcedureReport') AND name='Ref115179')
    PRINT '<<< CREATED INDEX ProcedureReport.Ref115179 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX ProcedureReport.Ref115179 >>>'
go

/* 
 * INDEX: State 
 */

CREATE INDEX State ON Process(State)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Process') AND name='State')
    PRINT '<<< CREATED INDEX Process.State >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Process.State >>>'
go

/* 
 * INDEX: Type 
 */

CREATE INDEX Type ON Process(Type)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Process') AND name='Type')
    PRINT '<<< CREATED INDEX Process.Type >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Process.Type >>>'
go

/* 
 * INDEX: Ref72200 
 */

CREATE INDEX Ref72200 ON Process(InitialDocumentId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Process') AND name='Ref72200')
    PRINT '<<< CREATED INDEX Process.Ref72200 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Process.Ref72200 >>>'
go

/* 
 * INDEX: Ref72201 
 */

CREATE INDEX Ref72201 ON Process(FinalDocumentId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Process') AND name='Ref72201')
    PRINT '<<< CREATED INDEX Process.Ref72201 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Process.Ref72201 >>>'
go

/* 
 * INDEX: Ref123326 
 */

CREATE INDEX Ref123326 ON Process(ExecutorId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Process') AND name='Ref123326')
    PRINT '<<< CREATED INDEX Process.Ref123326 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Process.Ref123326 >>>'
go

/* 
 * INDEX: Ref122205 
 */

CREATE INDEX Ref122205 ON Process_Document(ProcessId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Process_Document') AND name='Ref122205')
    PRINT '<<< CREATED INDEX Process_Document.Ref122205 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Process_Document.Ref122205 >>>'
go

/* 
 * INDEX: Ref72170 
 */

CREATE INDEX Ref72170 ON Process_Document(DocumentId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Process_Document') AND name='Ref72170')
    PRINT '<<< CREATED INDEX Process_Document.Ref72170 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Process_Document.Ref72170 >>>'
go

/* 
 * INDEX: Ref122322 
 */

CREATE INDEX Ref122322 ON ProcessEvent(ProcessId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('ProcessEvent') AND name='Ref122322')
    PRINT '<<< CREATED INDEX ProcessEvent.Ref122322 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX ProcessEvent.Ref122322 >>>'
go

/* 
 * INDEX: Ref72323 
 */

CREATE INDEX Ref72323 ON ProcessEvent(DocumentId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('ProcessEvent') AND name='Ref72323')
    PRINT '<<< CREATED INDEX ProcessEvent.Ref72323 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX ProcessEvent.Ref72323 >>>'
go

/* 
 * INDEX: Ref123324 
 */

CREATE INDEX Ref123324 ON ProcessEvent(ExecutorId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('ProcessEvent') AND name='Ref123324')
    PRINT '<<< CREATED INDEX ProcessEvent.Ref123324 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX ProcessEvent.Ref123324 >>>'
go

/* 
 * INDEX: Ref7309 
 */

CREATE INDEX Ref7309 ON PropertyClaim(ManagerProcedureId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('PropertyClaim') AND name='Ref7309')
    PRINT '<<< CREATED INDEX PropertyClaim.Ref7309 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX PropertyClaim.Ref7309 >>>'
go

/* 
 * INDEX: Ref121194 
 */

CREATE INDEX Ref121194 ON Request(RequestId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Request') AND name='Ref121194')
    PRINT '<<< CREATED INDEX Request.Ref121194 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Request.Ref121194 >>>'
go

/* 
 * INDEX: Ref122297 
 */

CREATE INDEX Ref122297 ON Sitting(SittingId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Sitting') AND name='Ref122297')
    PRINT '<<< CREATED INDEX Sitting.Ref122297 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Sitting.Ref122297 >>>'
go

/* 
 * INDEX: Ref106303 
 */

CREATE INDEX Ref106303 ON Sitting(ChairmanId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('Sitting') AND name='Ref106303')
    PRINT '<<< CREATED INDEX Sitting.Ref106303 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX Sitting.Ref106303 >>>'
go

/* 
 * INDEX: Ref139332 
 */

CREATE INDEX Ref139332 ON SittingParticipant(SittingId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('SittingParticipant') AND name='Ref139332')
    PRINT '<<< CREATED INDEX SittingParticipant.Ref139332 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX SittingParticipant.Ref139332 >>>'
go

/* 
 * INDEX: Ref106333 
 */

CREATE INDEX Ref106333 ON SittingParticipant(EconomicMemberId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('SittingParticipant') AND name='Ref106333')
    PRINT '<<< CREATED INDEX SittingParticipant.Ref106333 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX SittingParticipant.Ref106333 >>>'
go

/* 
 * INDEX: Ref122298 
 */

CREATE INDEX Ref122298 ON SittingQuestion(ProcessId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('SittingQuestion') AND name='Ref122298')
    PRINT '<<< CREATED INDEX SittingQuestion.Ref122298 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX SittingQuestion.Ref122298 >>>'
go

/* 
 * INDEX: Ref139300 
 */

CREATE INDEX Ref139300 ON SittingQuestion(SittingId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('SittingQuestion') AND name='Ref139300')
    PRINT '<<< CREATED INDEX SittingQuestion.Ref139300 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX SittingQuestion.Ref139300 >>>'
go

/* 
 * INDEX: Ref105295 
 */

CREATE INDEX Ref105295 ON SRO(LegalPersonId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('SRO') AND name='Ref105295')
    PRINT '<<< CREATED INDEX SRO.Ref105295 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX SRO.Ref105295 >>>'
go

/* 
 * INDEX: EconomicMemberKey 
 */

CREATE INDEX EconomicMemberKey ON SROMember(EconomicMemberId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('SROMember') AND name='EconomicMemberKey')
    PRINT '<<< CREATED INDEX SROMember.EconomicMemberKey >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX SROMember.EconomicMemberKey >>>'
go

/* 
 * INDEX: Type 
 */

CREATE INDEX Type ON SROMember(Type)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('SROMember') AND name='Type')
    PRINT '<<< CREATED INDEX SROMember.Type >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX SROMember.Type >>>'
go

/* 
 * INDEX: Ref138293 
 */

CREATE INDEX Ref138293 ON SROMember(SROId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('SROMember') AND name='Ref138293')
    PRINT '<<< CREATED INDEX SROMember.Ref138293 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX SROMember.Ref138293 >>>'
go

/* 
 * INDEX: Ref106211 
 */

CREATE INDEX Ref106211 ON SROMember(EconomicMemberId)
go
IF EXISTS (SELECT * FROM sysindexes WHERE id=OBJECT_ID('SROMember') AND name='Ref106211')
    PRINT '<<< CREATED INDEX SROMember.Ref106211 >>>'
ELSE
    PRINT '<<< FAILED CREATING INDEX SROMember.Ref106211 >>>'
go

/* 
 * TABLE: Accreditation 
 */

ALTER TABLE Accreditation ADD CONSTRAINT RefAccredited317 
    FOREIGN KEY (AccreditedId)
    REFERENCES Accredited(AccreditedId)
go

ALTER TABLE Accreditation ADD CONSTRAINT RefDocument321 
    FOREIGN KEY (DocumentId)
    REFERENCES Document(DocumentId)
go


/* 
 * TABLE: Accreditation_Line 
 */

ALTER TABLE Accreditation_Line ADD CONSTRAINT RefLineOfAccreditation284 
    FOREIGN KEY (LineOfAccreditationId)
    REFERENCES LineOfAccreditation(LineOfAccreditationId)
go

ALTER TABLE Accreditation_Line ADD CONSTRAINT RefAccreditation320 
    FOREIGN KEY (AccreditationId)
    REFERENCES Accreditation(AccreditationId) ON DELETE CASCADE
go


/* 
 * TABLE: Accreditation_Province 
 */

ALTER TABLE Accreditation_Province ADD CONSTRAINT RefAccreditation319 
    FOREIGN KEY (AccreditationId)
    REFERENCES Accreditation(AccreditationId) ON DELETE CASCADE
go

ALTER TABLE Accreditation_Province ADD CONSTRAINT RefProvince318 
    FOREIGN KEY (ProvinceId)
    REFERENCES Province(ProvinceId)
go


/* 
 * TABLE: Accredited 
 */

ALTER TABLE Accredited ADD CONSTRAINT RefSROMember145 
    FOREIGN KEY (AccreditedId)
    REFERENCES SROMember(SROMemberId)
go

ALTER TABLE Accredited ADD CONSTRAINT RefDocument271 
    FOREIGN KEY (DocumentId)
    REFERENCES Document(DocumentId)
go


/* 
 * TABLE: Address 
 */

ALTER TABLE Address ADD CONSTRAINT RefContactInfo236 
    FOREIGN KEY (AddressId)
    REFERENCES ContactInfo(ContactInfoId)
go

ALTER TABLE Address ADD CONSTRAINT RefProvince245 
    FOREIGN KEY (ProvinceId)
    REFERENCES Province(ProvinceId)
go


/* 
 * TABLE: AssetChange 
 */

ALTER TABLE AssetChange ADD CONSTRAINT RefManagerProcedure307 
    FOREIGN KEY (ManagerProcedureId)
    REFERENCES ManagerProcedure(ManagerProcedureId)
go

ALTER TABLE AssetChange ADD CONSTRAINT RefEconomicMember308 
    FOREIGN KEY (EconomicMemberId)
    REFERENCES EconomicMember(EconomicMemberId)
go


/* 
 * TABLE: Attachment 
 */

ALTER TABLE Attachment ADD CONSTRAINT RefDocument120 
    FOREIGN KEY (DocumentId)
    REFERENCES Document(DocumentId)
go

ALTER TABLE Attachment ADD CONSTRAINT RefOutcoming274 
    FOREIGN KEY (OutcomingId)
    REFERENCES Outcoming(OutcomingId)
go


/* 
 * TABLE: Audit 
 */

ALTER TABLE Audit ADD CONSTRAINT RefDiscipline288 
    FOREIGN KEY (DisciplineId)
    REFERENCES Discipline(DisciplineId)
go

ALTER TABLE Audit ADD CONSTRAINT RefBancruptcySubProcess168 
    FOREIGN KEY (AuditId)
    REFERENCES BancruptcySubProcess(BancruptcySubProcessId)
go


/* 
 * TABLE: BancruptcyProcess 
 */

ALTER TABLE BancruptcyProcess ADD CONSTRAINT RefBancruptcyProcess198 
    FOREIGN KEY (PreviousProcessId)
    REFERENCES BancruptcyProcess(BancruptcyProcessId)
go

ALTER TABLE BancruptcyProcess ADD CONSTRAINT RefProcess202 
    FOREIGN KEY (BancruptcyProcessId)
    REFERENCES Process(ProcessId)
go

ALTER TABLE BancruptcyProcess ADD CONSTRAINT RefEconomicMember225 
    FOREIGN KEY (CourtId)
    REFERENCES EconomicMember(EconomicMemberId)
go

ALTER TABLE BancruptcyProcess ADD CONSTRAINT RefEconomicMember227 
    FOREIGN KEY (DebtorId)
    REFERENCES EconomicMember(EconomicMemberId)
go

ALTER TABLE BancruptcyProcess ADD CONSTRAINT RefEconomicMember257 
    FOREIGN KEY (ApplicantId)
    REFERENCES EconomicMember(EconomicMemberId)
go


/* 
 * TABLE: BancruptcySubProcess 
 */

ALTER TABLE BancruptcySubProcess ADD CONSTRAINT RefProcess204 
    FOREIGN KEY (BancruptcySubProcessId)
    REFERENCES Process(ProcessId)
go

ALTER TABLE BancruptcySubProcess ADD CONSTRAINT RefManagerProcedure180 
    FOREIGN KEY (ProcedureId)
    REFERENCES ManagerProcedure(ManagerProcedureId)
go


/* 
 * TABLE: Bank 
 */

ALTER TABLE Bank ADD CONSTRAINT RefLegalPerson243 
    FOREIGN KEY (LegalPersonId)
    REFERENCES LegalPerson(LegalPersonId)
go


/* 
 * TABLE: BankAccount 
 */

ALTER TABLE BankAccount ADD CONSTRAINT RefBank231 
    FOREIGN KEY (BankId)
    REFERENCES Bank(BankId)
go

ALTER TABLE BankAccount ADD CONSTRAINT RefEconomicMember244 
    FOREIGN KEY (EconomicMemberId)
    REFERENCES EconomicMember(EconomicMemberId)
go


/* 
 * TABLE: Comission 
 */

ALTER TABLE Comission ADD CONSTRAINT RefEconomicMember208 
    FOREIGN KEY (EconomicMemberId)
    REFERENCES EconomicMember(EconomicMemberId)
go

ALTER TABLE Comission ADD CONSTRAINT RefSittingQuestion299 
    FOREIGN KEY (ProcessId)
    REFERENCES SittingQuestion(ProcessId) ON DELETE CASCADE
go


/* 
 * TABLE: Complaint 
 */

ALTER TABLE Complaint ADD CONSTRAINT RefAudit287 
    FOREIGN KEY (AuditId)
    REFERENCES Audit(AuditId)
go

ALTER TABLE Complaint ADD CONSTRAINT RefBancruptcySubProcess167 
    FOREIGN KEY (ComplaintId)
    REFERENCES BancruptcySubProcess(BancruptcySubProcessId)
go


/* 
 * TABLE: ContactInfo 
 */

ALTER TABLE ContactInfo ADD CONSTRAINT RefContactType239 
    FOREIGN KEY (ContactTypeId)
    REFERENCES ContactType(ContactTypeId)
go

ALTER TABLE ContactInfo ADD CONSTRAINT RefEconomicMember240 
    FOREIGN KEY (EconomicMemberId)
    REFERENCES EconomicMember(EconomicMemberId) ON DELETE CASCADE
go


/* 
 * TABLE: Deal 
 */

ALTER TABLE Deal ADD CONSTRAINT RefProcedureReport249 
    FOREIGN KEY (ProcedureReportId)
    REFERENCES ProcedureReport(ProcedureReportId) ON DELETE CASCADE
go

ALTER TABLE Deal ADD CONSTRAINT RefManagerProcedure262 
    FOREIGN KEY (ManagerProcedureId)
    REFERENCES ManagerProcedure(ManagerProcedureId)
go

ALTER TABLE Deal ADD CONSTRAINT RefEconomicMember266 
    FOREIGN KEY (EconomicMemberId)
    REFERENCES EconomicMember(EconomicMemberId)
go


/* 
 * TABLE: DealPlan 
 */

ALTER TABLE DealPlan ADD CONSTRAINT RefManagerProcedure305 
    FOREIGN KEY (ManagerProcedureId)
    REFERENCES ManagerProcedure(ManagerProcedureId) ON DELETE CASCADE
go

ALTER TABLE DealPlan ADD CONSTRAINT RefEconomicMember306 
    FOREIGN KEY (EconomicMemberId)
    REFERENCES EconomicMember(EconomicMemberId)
go


/* 
 * TABLE: Discipline 
 */

ALTER TABLE Discipline ADD CONSTRAINT RefProcess290 
    FOREIGN KEY (DisciplineId)
    REFERENCES Process(ProcessId)
go

ALTER TABLE Discipline ADD CONSTRAINT RefManager291 
    FOREIGN KEY (ManagerId)
    REFERENCES Manager(ManagerId)
go


/* 
 * TABLE: Document 
 */

ALTER TABLE Document ADD CONSTRAINT RefExecutor217 
    FOREIGN KEY (AuthorId)
    REFERENCES Executor(ExecutorId)
go

ALTER TABLE Document ADD CONSTRAINT RefExecutor334 
    FOREIGN KEY (EditorId)
    REFERENCES Executor(ExecutorId)
go


/* 
 * TABLE: DocumentAddress 
 */

ALTER TABLE DocumentAddress ADD CONSTRAINT RefDocumentChannel278 
    FOREIGN KEY (DocumentAddressId)
    REFERENCES DocumentChannel(DocumentChannelId)
go


/* 
 * TABLE: DocumentChannel 
 */

ALTER TABLE DocumentChannel ADD CONSTRAINT RefContactType275 
    FOREIGN KEY (ContactTypeId)
    REFERENCES ContactType(ContactTypeId)
go

ALTER TABLE DocumentChannel ADD CONSTRAINT RefEconomicMember279 
    FOREIGN KEY (EconomicMemberId)
    REFERENCES EconomicMember(EconomicMemberId)
go

ALTER TABLE DocumentChannel ADD CONSTRAINT RefIncoming282 
    FOREIGN KEY (IncomingId)
    REFERENCES Incoming(IncomingId)
go

ALTER TABLE DocumentChannel ADD CONSTRAINT RefDocumentTarget283 
    FOREIGN KEY (DocumentTargetId)
    REFERENCES DocumentTarget(DocumentTargetId)
go


/* 
 * TABLE: DocumentTarget 
 */

ALTER TABLE DocumentTarget ADD CONSTRAINT RefExecutor246 
    FOREIGN KEY (SenderId)
    REFERENCES Executor(ExecutorId)
go

ALTER TABLE DocumentTarget ADD CONSTRAINT RefExecutor247 
    FOREIGN KEY (ConfirmatorId)
    REFERENCES Executor(ExecutorId)
go

ALTER TABLE DocumentTarget ADD CONSTRAINT RefExecutor286 
    FOREIGN KEY (AuthorId)
    REFERENCES Executor(ExecutorId)
go

ALTER TABLE DocumentTarget ADD CONSTRAINT RefExecutor337 
    FOREIGN KEY (PackerId)
    REFERENCES Executor(ExecutorId)
go

ALTER TABLE DocumentTarget ADD CONSTRAINT RefExecutor338 
    FOREIGN KEY (PublisherId)
    REFERENCES Executor(ExecutorId)
go

ALTER TABLE DocumentTarget ADD CONSTRAINT RefOutcoming242 
    FOREIGN KEY (OutcomingId)
    REFERENCES Outcoming(OutcomingId) ON DELETE CASCADE
go

ALTER TABLE DocumentTarget ADD CONSTRAINT RefPostRegister254 
    FOREIGN KEY (PostRegisterId)
    REFERENCES PostRegister(PostRegisterId)
go


/* 
 * TABLE: EconomicMember 
 */

ALTER TABLE EconomicMember ADD CONSTRAINT RefIndustry226 
    FOREIGN KEY (IndustryId)
    REFERENCES Industry(IndustryId)
go

ALTER TABLE EconomicMember ADD CONSTRAINT EconomicMember_OrganizationForm 
    FOREIGN KEY (OKOPF)
    REFERENCES OrganizationalForm(OKOPF)
go

ALTER TABLE EconomicMember ADD CONSTRAINT EconomicMember_OwnershipForm 
    FOREIGN KEY (OKFS)
    REFERENCES OwnershipForm(OKFS)
go


/* 
 * TABLE: EconomicVariableSnapShot 
 */

ALTER TABLE EconomicVariableSnapShot ADD CONSTRAINT RefManagerProcedure310 
    FOREIGN KEY (ManagerProcedureId)
    REFERENCES ManagerProcedure(ManagerProcedureId) ON DELETE CASCADE
go

ALTER TABLE EconomicVariableSnapShot ADD CONSTRAINT RefEconomicVariableType311 
    FOREIGN KEY (EconomicVariableTypeId)
    REFERENCES EconomicVariableType(EconomicVariableTypeId)
go


/* 
 * TABLE: Education 
 */

ALTER TABLE Education ADD CONSTRAINT RefManager104 
    FOREIGN KEY (ManagerId)
    REFERENCES Manager(ManagerId) ON DELETE CASCADE
go


/* 
 * TABLE: Employee 
 */

ALTER TABLE Employee ADD CONSTRAINT RefLegalPerson259 
    FOREIGN KEY (LegalPersonId)
    REFERENCES LegalPerson(LegalPersonId)
go

ALTER TABLE Employee ADD CONSTRAINT RefNaturalPerson260 
    FOREIGN KEY (NaturalPersonId)
    REFERENCES NaturalPerson(NaturalPersonId)
go

ALTER TABLE Employee ADD CONSTRAINT RefEmployeePositionType261 
    FOREIGN KEY (EmployeePositionTypeId)
    REFERENCES EmployeePositionType(EmployeePositionTypeId)
go


/* 
 * TABLE: Executor 
 */

ALTER TABLE Executor ADD CONSTRAINT RefNaturalPerson216 
    FOREIGN KEY (NaturalPersonId)
    REFERENCES NaturalPerson(NaturalPersonId)
go


/* 
 * TABLE: Executor_role 
 */

ALTER TABLE Executor_role ADD CONSTRAINT RefRole126 
    FOREIGN KEY (RoleId)
    REFERENCES Role(RoleId) ON UPDATE CASCADE
go

ALTER TABLE Executor_role ADD CONSTRAINT RefExecutor214 
    FOREIGN KEY (ExecutorId)
    REFERENCES Executor(ExecutorId) ON DELETE CASCADE
go


/* 
 * TABLE: Experience 
 */

ALTER TABLE Experience ADD CONSTRAINT RefManager105 
    FOREIGN KEY (ManagerId)
    REFERENCES Manager(ManagerId) ON DELETE CASCADE
go

ALTER TABLE Experience ADD CONSTRAINT RefIndustry114 
    FOREIGN KEY (IndustryId)
    REFERENCES Industry(IndustryId)
go

ALTER TABLE Experience ADD CONSTRAINT RefEconomicMember258 
    FOREIGN KEY (EconomicMemberId)
    REFERENCES EconomicMember(EconomicMemberId)
go


/* 
 * TABLE: ExtensionField 
 */

ALTER TABLE ExtensionField ADD CONSTRAINT RefExtensionFieldType112 
    FOREIGN KEY (ExtensionFieldTypeId)
    REFERENCES ExtensionFieldType(ExtensionFieldTypeId)
go

ALTER TABLE ExtensionField ADD CONSTRAINT RefSROMember148 
    FOREIGN KEY (SROMemberId)
    REFERENCES SROMember(SROMemberId) ON DELETE CASCADE
go


/* 
 * TABLE: ExtraContactInfo 
 */

ALTER TABLE ExtraContactInfo ADD CONSTRAINT RefContactInfo237 
    FOREIGN KEY (ExtraContactInfoId)
    REFERENCES ContactInfo(ContactInfoId)
go


/* 
 * TABLE: ExtraDocumentChannel 
 */

ALTER TABLE ExtraDocumentChannel ADD CONSTRAINT RefDocumentChannel276 
    FOREIGN KEY (ExtraDocumentChannelId)
    REFERENCES DocumentChannel(DocumentChannelId)
go


/* 
 * TABLE: ExtraDocumentRequest 
 */

ALTER TABLE ExtraDocumentRequest ADD CONSTRAINT RefProcess250 
    FOREIGN KEY (ProcessId)
    REFERENCES Process(ProcessId)
go

ALTER TABLE ExtraDocumentRequest ADD CONSTRAINT RefOutcoming251 
    FOREIGN KEY (OutcomingId)
    REFERENCES Outcoming(OutcomingId)
go

ALTER TABLE ExtraDocumentRequest ADD CONSTRAINT RefIncoming252 
    FOREIGN KEY (IncomingId)
    REFERENCES Incoming(IncomingId)
go


/* 
 * TABLE: Filial 
 */

ALTER TABLE Filial ADD CONSTRAINT RefSROMember207 
    FOREIGN KEY (FilialId)
    REFERENCES SROMember(SROMemberId)
go


/* 
 * TABLE: Incoming 
 */

ALTER TABLE Incoming ADD CONSTRAINT RefDocument156 
    FOREIGN KEY (IncomingId)
    REFERENCES Document(DocumentId)
go


/* 
 * TABLE: LegalPerson 
 */

ALTER TABLE LegalPerson ADD CONSTRAINT RefEconomicMember129 
    FOREIGN KEY (LegalPersonId)
    REFERENCES EconomicMember(EconomicMemberId)
go


/* 
 * TABLE: Manager 
 */

ALTER TABLE Manager ADD CONSTRAINT RefSROMember144 
    FOREIGN KEY (ManagerId)
    REFERENCES SROMember(SROMemberId)
go

ALTER TABLE Manager ADD CONSTRAINT RefFilial98 
    FOREIGN KEY (FilialId)
    REFERENCES Filial(FilialId)
go


/* 
 * TABLE: ManagerProcedure 
 */

ALTER TABLE ManagerProcedure ADD CONSTRAINT RefBancruptcyProcess193 
    FOREIGN KEY (ManagerProcedureId)
    REFERENCES BancruptcyProcess(BancruptcyProcessId)
go

ALTER TABLE ManagerProcedure ADD CONSTRAINT RefManager23 
    FOREIGN KEY (ManagerId)
    REFERENCES Manager(ManagerId)
go


/* 
 * TABLE: MembershipEvent 
 */

ALTER TABLE MembershipEvent ADD CONSTRAINT RefDocument206 
    FOREIGN KEY (DocumentId)
    REFERENCES Document(DocumentId)
go

ALTER TABLE MembershipEvent ADD CONSTRAINT RefSROMember149 
    FOREIGN KEY (SROMemberId)
    REFERENCES SROMember(SROMemberId) ON DELETE CASCADE
go

ALTER TABLE MembershipEvent ADD CONSTRAINT RefExecutor325 
    FOREIGN KEY (ExecutorId)
    REFERENCES Executor(ExecutorId)
go


/* 
 * TABLE: NaturalPerson 
 */

ALTER TABLE NaturalPerson ADD CONSTRAINT RefEconomicMember128 
    FOREIGN KEY (NaturalPersonId)
    REFERENCES EconomicMember(EconomicMemberId)
go


/* 
 * TABLE: Offer 
 */

ALTER TABLE Offer ADD CONSTRAINT RefManager186 
    FOREIGN KEY (ManagerId)
    REFERENCES Manager(ManagerId)
go

ALTER TABLE Offer ADD CONSTRAINT RefRequest187 
    FOREIGN KEY (RequestId)
    REFERENCES Request(RequestId)
go

ALTER TABLE Offer ADD CONSTRAINT RefProcess203 
    FOREIGN KEY (OfferId)
    REFERENCES Process(ProcessId)
go


/* 
 * TABLE: Outcoming 
 */

ALTER TABLE Outcoming ADD CONSTRAINT RefDocument157 
    FOREIGN KEY (OutcomingId)
    REFERENCES Document(DocumentId)
go


/* 
 * TABLE: Payment 
 */

ALTER TABLE Payment ADD CONSTRAINT RefPaymentCategory312 
    FOREIGN KEY (PaymentCategoryId)
    REFERENCES PaymentCategory(PaymentCategoryId)
go

ALTER TABLE Payment ADD CONSTRAINT RefSROMember152 
    FOREIGN KEY (SROMemberId)
    REFERENCES SROMember(SROMemberId)
go

ALTER TABLE Payment ADD CONSTRAINT RefDeal328 
    FOREIGN KEY (DealId)
    REFERENCES Deal(DealId)
go

ALTER TABLE Payment ADD CONSTRAINT RefManagerProcedure327 
    FOREIGN KEY (ManagerProcedureId)
    REFERENCES ManagerProcedure(ManagerProcedureId)
go


/* 
 * TABLE: PostRegister 
 */

ALTER TABLE PostRegister ADD CONSTRAINT RefDocument253 
    FOREIGN KEY (DocumentId)
    REFERENCES Document(DocumentId)
go

ALTER TABLE PostRegister ADD CONSTRAINT RefExecutor255 
    FOREIGN KEY (ExecutorId)
    REFERENCES Executor(ExecutorId)
go


/* 
 * TABLE: ProcedureReport 
 */

ALTER TABLE ProcedureReport ADD CONSTRAINT RefDocument181 
    FOREIGN KEY (ResponseDocumentId)
    REFERENCES Document(DocumentId)
go

ALTER TABLE ProcedureReport ADD CONSTRAINT RefBancruptcySubProcess179 
    FOREIGN KEY (ProcedureReportId)
    REFERENCES BancruptcySubProcess(BancruptcySubProcessId)
go


/* 
 * TABLE: Process 
 */

ALTER TABLE Process ADD CONSTRAINT RefDocument200 
    FOREIGN KEY (InitialDocumentId)
    REFERENCES Document(DocumentId)
go

ALTER TABLE Process ADD CONSTRAINT RefDocument201 
    FOREIGN KEY (FinalDocumentId)
    REFERENCES Document(DocumentId)
go

ALTER TABLE Process ADD CONSTRAINT RefExecutor326 
    FOREIGN KEY (ExecutorId)
    REFERENCES Executor(ExecutorId)
go


/* 
 * TABLE: Process_Document 
 */

ALTER TABLE Process_Document ADD CONSTRAINT RefProcess205 
    FOREIGN KEY (ProcessId)
    REFERENCES Process(ProcessId) ON DELETE CASCADE
go

ALTER TABLE Process_Document ADD CONSTRAINT RefDocument170 
    FOREIGN KEY (DocumentId)
    REFERENCES Document(DocumentId)
go


/* 
 * TABLE: ProcessEvent 
 */

ALTER TABLE ProcessEvent ADD CONSTRAINT RefProcess322 
    FOREIGN KEY (ProcessId)
    REFERENCES Process(ProcessId)
go

ALTER TABLE ProcessEvent ADD CONSTRAINT RefDocument323 
    FOREIGN KEY (DocumentId)
    REFERENCES Document(DocumentId)
go

ALTER TABLE ProcessEvent ADD CONSTRAINT RefExecutor324 
    FOREIGN KEY (ExecutorId)
    REFERENCES Executor(ExecutorId)
go


/* 
 * TABLE: PropertyClaim 
 */

ALTER TABLE PropertyClaim ADD CONSTRAINT RefManagerProcedure309 
    FOREIGN KEY (ManagerProcedureId)
    REFERENCES ManagerProcedure(ManagerProcedureId) ON DELETE CASCADE
go


/* 
 * TABLE: Request 
 */

ALTER TABLE Request ADD CONSTRAINT RefBancruptcyProcess194 
    FOREIGN KEY (RequestId)
    REFERENCES BancruptcyProcess(BancruptcyProcessId)
go


/* 
 * TABLE: Sitting 
 */

ALTER TABLE Sitting ADD CONSTRAINT RefProcess297 
    FOREIGN KEY (SittingId)
    REFERENCES Process(ProcessId)
go

ALTER TABLE Sitting ADD CONSTRAINT RefEconomicMember303 
    FOREIGN KEY (ChairmanId)
    REFERENCES EconomicMember(EconomicMemberId)
go


/* 
 * TABLE: SittingParticipant 
 */

ALTER TABLE SittingParticipant ADD CONSTRAINT RefSitting332 
    FOREIGN KEY (SittingId)
    REFERENCES Sitting(SittingId)
go

ALTER TABLE SittingParticipant ADD CONSTRAINT RefEconomicMember333 
    FOREIGN KEY (EconomicMemberId)
    REFERENCES EconomicMember(EconomicMemberId)
go


/* 
 * TABLE: SittingQuestion 
 */

ALTER TABLE SittingQuestion ADD CONSTRAINT RefProcess298 
    FOREIGN KEY (ProcessId)
    REFERENCES Process(ProcessId)
go

ALTER TABLE SittingQuestion ADD CONSTRAINT RefSitting300 
    FOREIGN KEY (SittingId)
    REFERENCES Sitting(SittingId)
go


/* 
 * TABLE: SRO 
 */

ALTER TABLE SRO ADD CONSTRAINT RefLegalPerson295 
    FOREIGN KEY (LegalPersonId)
    REFERENCES LegalPerson(LegalPersonId)
go


/* 
 * TABLE: SROMember 
 */

ALTER TABLE SROMember ADD CONSTRAINT RefSRO293 
    FOREIGN KEY (SROId)
    REFERENCES SRO(SROId)
go

ALTER TABLE SROMember ADD CONSTRAINT RefEconomicMember211 
    FOREIGN KEY (EconomicMemberId)
    REFERENCES EconomicMember(EconomicMemberId)
go


